<?php
class Easy_Folders_Import_Controller
{
    /**
     * Class instance
     * @since 1.0.0
    */
    protected static $instance = null;

    /**
     * Return class instance only
     * @since 1.0.0
     * @return object
    */
    public static function getInstance()
    {
        if (null == self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /**
     * Import & Export api routes
     * @since 1.0.0
     * @return void
     */
    public function routes()
    {
        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'settings/media-plugins',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'index'),
                'permission_callback' => function () {
                    $capability = is_multisite() ? 'manage_network' : 'manage_options';
                    return current_user_can($capability);
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'settings/media-plugin-import',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'startImport'),
                'permission_callback' => function () {
                    $capability = is_multisite() ? 'manage_network' : 'manage_options';
                    return current_user_can($capability);
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'settings/import-insert-folder',
            array(
                'methods' => 'PUT',
                'callback' => array($this, 'addFolders'),
                'permission_callback' => function () {
                    $capability = is_multisite() ? 'manage_network' : 'manage_options';
                    return current_user_can($capability);
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'settings/after-import',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'afterImport'),
                'permission_callback' => function () {
                    $capability = is_multisite() ? 'manage_network' : 'manage_options';
                    return current_user_can($capability);
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'settings/import-easy-folders-content',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'import'),
                'permission_callback' => function () {
                    $capability = is_multisite() ? 'manage_network' : 'manage_options';
                    return current_user_can($capability);
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'settings/delete-plugin-data',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'deletePluginData'),
                'permission_callback' => function () {
                    $capability = is_multisite() ? 'manage_network' : 'manage_options';
                    return current_user_can($capability);
                }
            )
        );
    }

    /**
     * Return other plugins to be Import
     * @since 1.0.0
     * @return JSON
     */
    public function index()
    {
        $enhancedFolder = count(Easy_Folders_Import::enhancedFolders(0, true));

        $wpmlfFolder = count(Easy_Folders_Import::wpmlfFolders(0, true));

        $wpmfFolder = count(Easy_Folders_Import::wpmfFolders(0, true));

        $realMediaFolder = count(Easy_Folders_Import::realMediaFolders(-1, true));

        $filebirdFolder = count(Easy_Folders_Import::FilebirdFolders(0, true));
        
        $happyFiles = count(Easy_Folders_Import::HappyFilesFolders(0, true));

        $wickedFolder = count(Easy_Folders_Import::taxonomyBasedFolders(0, true, 'wicked_folders'));

        $premioFolder = count(Easy_Folders_Import::taxonomyBasedFolders(0, true, 'premio_folders'));

        wp_send_json_success([
            'countEnhancedFolder' => $enhancedFolder,
            'countWpmlfFolder' => $wpmlfFolder,
            'countWpmfFolder' => $wpmfFolder,
            'countRealMediaFolder' => $realMediaFolder,
            'countHappyFiles' => $happyFiles,
            'countFilebirdFolder' => $filebirdFolder,
            'countWickedFolder' => $wickedFolder,
            'countPremioFolder' => $premioFolder,
        ]);
    }

    /**
     * Start import plugin process
     * @since 1.0.0
     * @param  mixed $request
     * @return JSON
     */
    public function startImport($request)
    {
        $site = sanitize_text_field($request->get_param('site'));

        $site = isset($site) ? sanitize_text_field($site) : '';

        $this->checkStatus($site);

        $folders = $this->getAllData($site, true);

        $count = count($folders);

        $folders = array_chunk($folders, 20);

        wp_send_json_success(array(
            'folders' => $folders,
            'count' => $count,
            'site' => $site
        ));
    }

    /**
     * Detect plugin somewhere is already imported
     * @since 1.0.0
     * @param  string $site
     * @return JSON
    */
    private function checkStatus($site)
    {
        //Clean data
        Easy_Folders_Import::clean();

        if ($site == 'wpmlf') {
            if (get_option('easyfolders_updated_from_wpmlf', '0') == '1') {
                wp_send_json_success(array(
                    'message' => __('Already imported', 'easy-folders')
                ));
            }
        } elseif ($site == 'enhanced') {
            if (get_option('easyfolders_updated_from_enhanced', '0') == '1') {
                wp_send_json_success(array(
                    'message' => __('Already imported', 'easy-folders')
                ));
            }
        } elseif ($site == 'wpmf') {
            if (get_option('easyfolders_updated_from_wpmf', '0') == '1') {
                wp_send_json_success(array(
                    'message' => __('Already imported', 'easy-folders')
                ));
            }
        } elseif ($site == 'happyfiles') {
            if (get_option('easyfolders_updated_from_happyfiles', '0') == '1') {
                wp_send_json_success(array(
                    'message' => __('Already imported', 'easy-folders')
                ));
            }
        } elseif ($site == 'realmedia') {
            if (get_option('easyfolders_updated_from_realmedia', '0') == '1') {
                wp_send_json_success(array(
                    'message' => __('Already imported', 'easy-folders')
                ));
            }
        } elseif ($site == 'filebird') {
            if (get_option('easyfolders_updated_from_filebird', '0') == '1') {
                wp_send_json_success(array(
                    'message' => __('Already imported', 'easy-folders')
                ));
            }
        } elseif ($site == 'wicked_folders') {
            if (get_option('easyfolders_updated_from_wicked_folders', '0') == '1') {
                wp_send_json_success(array(
                    'message' => __('Already imported', 'easy-folders')
                ));
            }
        } elseif ($site == 'premio_folders') {
            if (get_option('easyfolders_updated_from_premio_folders', '0') == '1') {
                wp_send_json_success(array(
                    'message' => __('Already imported', 'easy-folders')
                ));
            }
        }
    }

    /**
     * Return relevant plugin folders
     * @since 1.0.0
     * @param  string $site
     * @param  boolean $flat
     * @return Array
    */
    public function getAllData($site, $flat = false)
    {
        $folders = array();

        if ($site == 'enhanced') {
            $folders = Easy_Folders_Import::enhancedFolders(0, $flat);
        } elseif ($site == 'wpmlf') {
            $folders = Easy_Folders_Import::wpmlfFolders(0, $flat);
        } elseif ($site == 'wpmf') {
            $folders = Easy_Folders_Import::wpmfFolders(0, $flat);
        } elseif ($site == 'realmedia') {
            $folders = Easy_Folders_Import::realMediaFolders(-1, $flat);
            foreach ($folders as $k => $folder) {
                $folders[$k]->parent = $folder->parent == '-1' ? 0 : $folder->parent;
            }
        } elseif ($site == 'filebird') {
            $folders = Easy_Folders_Import::FilebirdFolders(0, $flat);
            foreach ($folders as $k => $folder) {
                $folders[$k]->parent = $folder->parent == '-1' ? 0 : $folder->parent;
            }
        } elseif ($site == 'happyfiles') {
            $folders = Easy_Folders_Import::HappyFilesFolders(0, $flat);
        } elseif (in_array($site, ["wicked_folders", "premio_folders"])) {
            $folders = Easy_Folders_Import::taxonomyBasedFolders(0, $flat, $site);
        }

        return $folders;
    }

    /**
     * Add folders to our system
     * @since 1.0.0
     * @param  mixed $request
     * @return JSON
    */
    public function addFolders($request)
    {
        $site = sanitize_text_field($request->get_param('site'));

        $folders = Easy_Folders_Helper::sanitizeArray($request->get_param('folders'));

        $site = isset($site) ? sanitize_text_field($site) : '';

        $folders = isset($folders) ? Easy_Folders_Helper::sanitizeArray($folders) : '';

        foreach ((array)$folders as $k => $folder) {
            if (\is_array($folder)) {
                $folder = json_decode(json_encode($folder));
            }
            $new_parent = $folder->parent;
            if ($new_parent > 0) {
                $new_parent = get_option('new_term_id_' . $new_parent);
            }
            $inserted = Easy_Folders_Media::save($folder->title, $new_parent, true, $folder->post_type);
            update_option('new_term_id_' . $folder->id, $inserted);
            $atts = $this->getAttachmentsOfFolder($site, $folder);
            Easy_Folders_Media::attachFoldersToPosts($atts, $inserted);
        }

        wp_send_json_success();
    }

    /**
     * Return attachments of relevant folder
     * @since 1.0.0
     * @param  string $site
     * @param  mixed $folder
     * @return ARRAY
    */
    public function getAttachmentsOfFolder($site, $folder)
    {
        global $wpdb;

        $attachments = array();

        if (is_array($folder)) {
            $folder = json_decode(json_encode($folder));
        }

        if (in_array($site, ['happyfiles', 'wpmf', 'enhanced', 'wicked_folders', 'premio_folders'])) {
            $attachments = $wpdb->get_col($wpdb->prepare('SELECT object_id FROM %1$s WHERE term_taxonomy_id = %2$d', $wpdb->term_relationships, $folder->term_taxonomy_id));
        } elseif ($site == 'realmedia') {
            $folder_table = $wpdb->prefix . 'realmedialibrary_posts';
            $attachments = $wpdb->get_col($wpdb->prepare('SELECT attachment FROM %1$s WHERE fid = %2$d', $folder_table, $folder->id));
        } elseif ($site == 'wpmlf') {
            $folder_table = $wpdb->prefix . 'mgmlp_folders';
            $sql = $wpdb->prepare("select ID from {$wpdb->prefix}posts 
                        LEFT JOIN $folder_table ON({$wpdb->prefix}posts.ID = $folder_table.post_id)
                        LEFT JOIN {$wpdb->prefix}postmeta AS pm ON (pm.post_id = {$wpdb->prefix}posts.ID) 
                        where post_type = 'attachment' 
                        and folder_id = %s
                        AND pm.meta_key = '_wp_attached_file' 
                        order by post_date desc", $folder->id);
            $attachments = $wpdb->get_col($sql);
        } elseif ($site == 'filebird') {
            $folder_table = $wpdb->prefix . 'fbv_attachment_folder';
            $attachments = $wpdb->get_col($wpdb->prepare('SELECT attachment_id FROM %1$s WHERE folder_id = %2$d', $folder_table, $folder->id));
        }

        return $attachments;
    }

    /**
     * After import
     * @since 1.0.0
     * @param  mixed $request
     * @return JSON
    */
    public function afterImport($request)
    {
        $reload = false;

        $site = sanitize_text_field($request->get_param('site'));

        $count = sanitize_text_field($request->get_param('count'));

        $installation_step = sanitize_text_field($request->get_param('installation_step'));

        $site = isset($site) ? sanitize_text_field($site) : '';

        $count = isset($count) ? sanitize_text_field($count) : '';

        $this->deleteTermData($site);

        if ($site == 'wpmf') {
            update_option('easyfolders_updated_from_wpmf', '1');
        } elseif ($site == 'wpmlf') {
            update_option('easyfolders_updated_from_wpmlf', '1');
        } elseif ($site == 'realmedia') {
            update_option('easyfolders_updated_from_realmedia', '1');
        } elseif ($site == 'filebird') {
            update_option('easyfolders_updated_from_filebird', '1');
        } elseif ($site == 'happyfiles') {
            update_option('easyfolders_updated_from_happyfiles', '1');
        } elseif ($site == 'enhanced') {
            update_option('easyfolders_updated_from_enhanced', '1');
        } elseif ($site == 'wicked_folders') {
            update_option('easyfolders_updated_from_wicked_folders', '1');
        } elseif ($site == 'premio_folders') {
            update_option('easyfolders_updated_from_premio_folders', '1');
        }

        $mess = sprintf(__('Congratulations! We have successfully imported %d folders into Easy Folders', 'easy-folders'), $count);

        if ($installation_step == "import-data") {
            Easy_Folders_Settings::installationStep($installation_step);
            $reload = true;
        }

        //Clean data
        Easy_Folders_Import::clean();
        
        wp_send_json_success(array(
            'message' => $mess,
            'reload' => $reload
        ));
    }

    /**
     * Delete some useless term meta data
     * @since 1.0.0
     * @return void
    */
    private function deleteTermData()
    {
        global $wpdb;
        $wpdb->delete($wpdb->termmeta, array('meta_key' => 'old_term_id'));
    }

    /**
     * Export EasyFolders media folders and its assigned attachments
     * @since 1.0.0
     * @return void
    */
    public function export()
    {
        set_time_limit(0);

        // phpcs:ignore WordPress.Security.NonceVerification.Recommended -- No action, nonce is not required
        if (!isset($_GET['action']) || $_GET['action'] !== 'easy-folders-export') {
            return;
        }

        if (!defined('WXR_VERSION')) {
            define('WXR_VERSION', '1.2');
        }

        $export_type = isset($_GET['export_type']) ? sanitize_text_field($_GET['export_type']) : 'folders';

        $folders = Easy_Folders_Tree::getAllData(null, true);

        $filename = 'EasyFolders-.' . date('Y-m-d H:i:s') . '.xml';

        header('Content-Description: File Transfer');

        header('Content-Type: text/xml; charset=' . get_option('blog_charset'), true);

        header('Content-Disposition: attachment; filename=' . $filename);

        echo '<?xml version="1.0" encoding="' . esc_html(get_bloginfo('charset')) . "\" ?>\n";
        // phpcs:disable WordPress.Security.EscapeOutput.OutputNotEscaped -- Render to XML file
        ?>
        <?php the_generator('export'); ?>
        <rss version="2.0" xmlns:excerpt="http://wordpress.org/export/<?php echo WXR_VERSION; ?>/excerpt/" xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:wfw="http://wellformedweb.org/CommentAPI/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:wp="http://wordpress.org/export/<?php echo WXR_VERSION; ?>/">
            <channel>
                <title><?php bloginfo('name'); ?></title>
                <link><?php bloginfo('url'); ?></link>
                <description><?php bloginfo('description'); ?></description>
                <pubDate><?php echo date('D, d M Y H:i:s +0000'); ?></pubDate>
                <language><?php bloginfo('language'); ?></language>
                <wp:wxr_version><?php echo WXR_VERSION; ?></wp:wxr_version>
                <wp:base_site_url><?php echo Easy_Folders_Helper::wxrSiteUrl(); ?></wp:base_site_url>
                <wp:base_blog_url><?php bloginfo('url'); ?></wp:base_blog_url>
                <?php
                if (in_array($export_type, ["folders", "all"])) {
                    //Folder hirerchcy
                    foreach ($folders as $folder) {
                        ?>
                        <folder>
                            <id><?php esc_html_e($folder['id'], 'easy-folders'); ?></id>
                            <text><?php esc_html_e($folder['text'], 'easy-folders'); ?></text>
                            <parent><?php esc_html_e($folder['parent'], 'easy-folders'); ?></parent>
                            <color><?php esc_html_e($folder['color'], 'easy-folders'); ?></color>
                            <starred><?php esc_html_e($folder['starred'], 'easy-folders'); ?></starred>
                        </folder>
                    <?php
                    }
                    //Folder relations
                    $relations = Easy_Folders_Media::getFolderMediaRelations();

                    foreach ($relations as $attachment => $folder) {
                        ?>
                        <relation>
                            <folder><?php esc_html_e(is_array($folder) ? implode(",", $folder) : $folder, 'easy-folders'); ?></folder>
                            <attachment><?php esc_html_e(is_array($attachment) ? implode(",", $attachment) : $attachment, 'easy-folders'); ?></attachment>
                        </relation>
                <?php
                    }
                }
                if (in_array($export_type, ["settings", "all"])) {
                    //Pending for future
                }
        ?>
            </channel>
        </rss>
        <?php
        die();
    }

    /**
     * Import EasyFolders media folders and its assigned attachments
     * @since 1.0.0
     * @param mixed $request
     * @return JSON
    */
    public function import($request)
    {
        try {
            $params = $request->get_file_params('file');

            if (isset($params['file']) and is_uploaded_file($params['file']['tmp_name'])) {
                $pathinfo = pathinfo($params['file']['name']);

                $extension = strtolower($pathinfo['extension']);

                $extensions_allowed = array("xml");

                $types_allowed = array("application/xml", "text/xml");

                if (!in_array($params['file']["type"], $types_allowed)) {
                    wp_send_json_error([
                        "success" => false,
                        "message" => __("Selected file type is not allowed", 'easy-folders')
                    ]);
                }

                if (in_array($extension, $extensions_allowed)) {
                    $import_data = $this->parse($params['file']["tmp_name"]);

                    Easy_Folders_Media::importFolders($import_data);

                    wp_send_json_success([
                        "success" => false,
                        "message" => __("Imported successfully", 'easy-folders')
                    ]);
                } else {
                    wp_send_json_error([
                        "success" => false,
                        "message" => __("Not allowed", 'easy-folders')
                    ]);
                }
            } else {
                if (!is_uploaded_file($params['file']['tmp_name'])) {
                    wp_send_json_error([
                        "success" => false,
                        "message" => __("Please choose file to upload", 'easy-folders')
                    ]);
                }
            }
        } catch (Exception $e) {
            wp_send_json_error([
                "success" => false,
                "message" => $e->getMessage()
            ]);
        }
    }

    /**
     * Delete plugin data
     * @since 1.0.0
     * @param mixed $request
     * @return JSON
    */
    public function deletePluginData($request)
    {
        $plugin = sanitize_text_field($request->get_param('plugin'));

        $response = Easy_Folders_Import::deletePluginData($plugin);

        $installation_step = sanitize_text_field($request->get_param('installation_step'));

        if ($installation_step == "import-data") {
            Easy_Folders_Settings::installationStep($installation_step);
            $response['reload'] = true;
        } else {
            $response['reload'] = false;
        }

        wp_send_json_success($response);
    }

    /**
     * Parse a WXR file
     * @since 1.0.0
     * @param string $file Path to WXR file for parsing
     * @return array Information gathered from the WXR file
     */
    public function parse($file)
    {
        $parser = new WXR_Parser();
        return $parser->parse($file);
    }
}
