<?php

class Easy_Folders_Media_Controller
{
    /**
     * Routes
     * @since 1.0.0
     * @return void
    */
    public function routes()
    {
        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'get-all-data',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'getAllData'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'get-trashed-folders',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'getTrashedFolders'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        

        

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'get-folders',
            array(
                'methods' => 'GET',
                'callback' => array($this, 'getAllFolders'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'create-folder',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'createFolder'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'save-folder',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'saveFolder'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'delete-folder-file',
            array(
                'methods' => 'PUT',
                'callback' => array($this, 'deleteItems'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        

        

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'move-to-folder',
            array(
                'methods' => 'PUT',
                'callback' => array($this, 'moveToFolder'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'restore-items',
            array(
                'methods' => 'PUT',
                'callback' => array($this, 'restoreItems'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'empty-bin',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'emptyBin'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'move-to-uncategorized',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'moveToUncategorized'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'move-to-root',
            array(
                'methods' => 'POST',
                'callback' => array($this, 'moveToRoot'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        register_rest_route(
            EASY_FOLDERS_REST_API_PREFIX,
            'fetch-attachments',
            array(
                'methods' => 'PUT',
                'callback' => array($this, 'fetchAttachments'),
                'permission_callback' => function () {
                    return current_user_can('upload_files');
                }
            )
        );

        

        

        
    }

    /**
     * Update get posts clauses
     * @since 1.0.0
     * @param $clauses
     * @param $query
     * @return array
    */
    public function customizedPostsClauses($clauses, $query)
    {
        global $wpdb;

        $folder = $query->get('efs');

        if (isset($_GET['efs']) || $folder !== '') {

            $folder = isset($_GET['efs']) ? (int)sanitize_text_field($_GET['efs']) : (int)$folder;

            $query_params = $query->query;

            $query_params['efs'] = $folder;

            update_option('efs-query-params-'.$query->get("post_type"), array_intersect_key($query_params, array_flip(['efs'])));

            $table_name = $wpdb->prefix . 'efs_attachment_folder';

            if (in_array($folder, [-1, 1])) {
                $attachment_ids = Easy_Folders_Media::getFoldersTrashedAttachments(false, $query->get("post_type"));
                if (!empty($attachment_ids)) {
                    $clauses['where'] .= " AND {$wpdb->posts}.ID NOT IN(" . implode(',', $attachment_ids) . ")";
                }
                if ($folder == 1) {
                    $attachment_ids = Easy_Folders_Media::getStarredItems();
                    if (!empty($attachment_ids)) {
                        $clauses['where'] .= " AND {$wpdb->posts}.ID IN(" . implode(',', $attachment_ids) . ")";
                    } else {
                        $clauses['where'] .= " AND {$wpdb->posts}.ID < 0"; // Show no starred attachments
                    }
                }
                return $clauses;
            } elseif ($folder === 2) {
                $attachment_ids = Easy_Folders_Media::getFoldersTrashedAttachments(false, $query->get("post_type"));
                $clauses['where'] = " AND {$wpdb->posts}.post_type = '".$query->get("post_type")."' AND {$wpdb->posts}.post_status = 'trash'";
                if (!empty($attachment_ids)) {
                    $clauses['where'] .= " AND {$wpdb->posts}.ID NOT IN(" . implode(',', $attachment_ids) . ")";
                }
                return $clauses;
            } elseif ($folder === 0) {
                $folder_attachments = Easy_Folders_Media::getUserFolderMediaRelations($query->get("post_type"));
                if($folder_attachments) {
                    $clauses['where'] .= " AND {$wpdb->posts}.ID NOT IN ($folder_attachments)";
                }
            } else {
                $clauses['join'] .= $wpdb->prepare(" LEFT JOIN {$table_name} AS efsa ON efsa.attachment_id = {$wpdb->posts}.ID AND efsa.folder_id = %d AND efsa.deleted_at IS NULL", $folder);
                $clauses['where'] .= " AND efsa.folder_id IS NOT NULL";
            }
            
        }

        return $clauses;
    }

    /**
     * Add attachment
     * @since 1.0.0
     * @param $post_id
     * @return void
    */
    public function addAttachment($post_id)
    {
        $folder = ((isset($_REQUEST['efs'])) ? sanitize_text_field($_REQUEST['efs']) : '');
        $path = ((isset($_REQUEST['path'])) ? sanitize_text_field($_REQUEST['path']) : '');
        if (in_array($folder, [-1, 0, 1, 2])) {
            $parent = 0;
        } else {
            $parent = $folder;
        }
        if ($path) {
            $path = explode('/', ltrim(rtrim($path, '/'), '/'));
            foreach ($path as $k => $v) {
                $parent = Easy_Folders_Media::save($v, $parent);
            }
        }
        Easy_Folders_Media::attachFoldersToPosts($post_id, $parent);
    }

    /**
     * Set attachment Args
     * @since 1.0.0
     * @param $query
     * @return array
    */
    public function setQueryAttachmentsArgs($query)
    {
        if (isset($_REQUEST['query']['efs']) || isset($_REQUEST['query']['orderby'])) {
            if(isset($_REQUEST['query']['efs'])) {
                $folder = sanitize_text_field($_REQUEST['query']['efs']);
    
                if (is_array($folder)) {
                    $folder = array_map('intval', $folder);
                } else {
                    $folder = intval($folder);
                }
    
                $query['trash'] = isset($_REQUEST['query']['trash']) && sanitize_text_field($_REQUEST['query']['trash']) ? true : false;
    
                $query['efs'] = $folder;
            } else {
                if(get_option('efs-query-params-attachment')) {
                    $query = array_merge($query, get_option('efs-query-params-attachment'));
                }
            }
            if(isset($_REQUEST['query']['orderby']) && $_REQUEST['query']['orderby']) {
                $query['orderby'] = sanitize_text_field($_REQUEST['query']['orderby']);
            }
        }

        return $query;
    }

    /**
     * Get all data
     * @since 1.0.0
     * @param $request
     * @return JSON
    */
    public static function getAllData($request)
    {
        $post_type = is_object($request) && $request instanceof WP_REST_Request ? sanitize_text_field($request->get_param('post_type')) : $request;

        $query = get_option('efs-query-params-'.$post_type) ? get_option('efs-query-params-'.$post_type) : [];

        $option = 'reset';

        $sort = isset($_POST['sort']) && $_POST['sort'] ? sanitize_text_field($_POST['sort']) : (isset($query['sortFolderBy']) && $query['sortFolderBy'] ? $query['sortFolderBy'] : "name_asc");

        $language = isset($_GET['lang']) ? sanitize_text_field($_GET['lang']) : null;

        $order = null;

        $post_type = isset($_POST['post_type']) && $_POST['post_type'] ? sanitize_text_field($_POST['post_type']) : $post_type;
        
        if (isset($sort) && \in_array(sanitize_text_field($sort), array('name_desc', 'reset', 'name_asc'))) {
            if (sanitize_text_field($sort) == 'name_asc') {
                $order = 'CAST(name as unsigned), name ASC';
                $option = sanitize_text_field($sort);
            } elseif (sanitize_text_field($sort) == 'name_desc') {
                $order = 'CAST(name as unsigned) DESC, name DESC';
                $option = sanitize_text_field($sort);
            }
            update_option('easyfolders_sort_folder', $option);
        } else {
            $easyfolders_sort_folder = get_option('easyfolders_sort_folder', 'reset');
            if ($easyfolders_sort_folder == 'reset') {
                $order = null;
            } elseif ($easyfolders_sort_folder == 'name_asc') {
                $order = 'name asc';
            } elseif ($easyfolders_sort_folder == 'name_desc') {
                $order = 'name desc';
            }
        }

        $tree = Easy_Folders_Tree::getAllData($order, false, 0, false, false, false, $post_type);

        $foldersCount = is_null($language) ? Easy_Folders_Tree::getFoldersCount(null, $post_type) : Easy_Folders_Tree::getFoldersCount($language, $post_type);

        $total = is_null($language) ? Easy_Folders_Tree::getFolderCount(-1, null, $post_type) : Easy_Folders_Tree::getFolderCount(-1, $language, $post_type);

        $categorizedAttachmentsCount = Easy_Folders_Media::getCategorizedAttachmentsCount(true, $post_type);

        $total_uncategorized = ($total - $categorizedAttachmentsCount);

        $months = Easy_Folders_Media::getMediaMonthsFilter();

        $response = array(
            'months' => $months,
            'mime_types' =>  Easy_Folders_Media::getMimetypes(),
            'tree' => $tree,
            'totalFolders' => Easy_Folders_Tree::getFolderChildrensIds($tree),
            'folder_count' => array(
                'total' => $total,
                'starred' => Easy_Folders_Media::getStarredItemsCount($post_type),
                'trashed' => (int)Easy_Folders_Media::getTrashedItemsCount(true, $post_type),
                'total_uncategorized' => $total_uncategorized,
                'folders' => $foldersCount,
            )
        );

        if (wp_is_json_request()) {
            wp_send_json_success($response);
        } else {
            return $response;
        }
    }

    /**
     * Get trashed folders
     * @since 1.0.0
     * @param $request
     * @return JSON
    */
    public static function getTrashedFolders($request = 'attachment')
    {
        $post_type = is_object($request) && $request instanceof WP_REST_Request ? sanitize_text_field($request->get_param('post_type')) : $request;

        $query = get_option('efs-query-params-'.$post_type) ? get_option('efs-query-params-'.$post_type) : [];

        $order = null;

        $option = 'reset';

        $sort = $_POST['sort'] ? sanitize_text_field($_POST['sort']) : (isset($query['sortFolderBy']) && $query['sortFolderBy'] ? $query['sortFolderBy'] : "name_asc");

        if (isset($sort) && \in_array(sanitize_text_field($sort), array('name_asc', 'name_desc', 'reset'))) {
            if (sanitize_text_field($sort) == 'name_asc') {
                $order = 'CAST(name as unsigned), name ASC';
                $option = sanitize_text_field($sort);
            } elseif (sanitize_text_field($sort) == 'name_desc') {
                $order = 'CAST(name as unsigned) DESC, name DESC';
                $option = sanitize_text_field($sort);
            }
            update_option('easyfolders_sort_folder', $option);
        } else {
            $easyfolders_sort_folder = get_option('easyfolders_sort_folder', 'reset');
            if ($easyfolders_sort_folder == 'reset') {
                $order = null;
            } elseif ($easyfolders_sort_folder == 'name_asc') {
                $order = 'name asc';
            } elseif ($easyfolders_sort_folder == 'name_desc') {
                $order = 'name desc';
            }
        }

        $response = Easy_Folders_Media::getTrashedFolders($order, $post_type);

        if (wp_is_json_request()) {
            wp_send_json_success($response);
        } else {
            return $response;
        }
    }

    /**
     * Get all folders
     * @since 1.0.0
     * @return JSON
    */
    public function getAllFolders()
    {
        $_folders = Easy_Folders_Tree::getAllData(null, true, 0, true);

        $folders = array(
            array(
                'value' => 0,
                'label' => __('Please choose folder', 'easy-folders'),
                'disabled' => true
            )
        );
        foreach ($_folders as $k => $v) {
            $folders[] = array(
                'value' => $v['id'],
                'label' => $v['text']
            );
        }

        wp_send_json_success($folders);
    }

    /**
     * New folder
     * @since 1.0.0
     * @param $request
     * @return JSON
    */
    public function createFolder($request)
    {
        $post_type = sanitize_text_field($request->get_param('post_type'));

        $name = sanitize_text_field($request->get_param('name'));

        $parent = sanitize_text_field($request->get_param('parent'));

        $parent = in_array($parent, [1, 2, 0]) ? "-1" : $parent;

        $name = isset($name) ? sanitize_text_field(wp_unslash($name)) : '';

        $parent = isset($parent) ? sanitize_text_field($parent) : '';

        if ($name != '' && $parent != '') {
            $insert = Easy_Folders_Media::save($name, $parent, false, $post_type);

            if ($insert !== false) {
                $message = sprintf(__('"%1$s" created successfully', 'easy-folders'), $name);

                wp_send_json_success(
                    array(
                        'mess' => $message
                    )
                );
            } else {
                wp_send_json_error(array('mess' => sprintf(__('A folder named "%1$s" already exist', 'easy-folders'), $name)));
            }
        } else {
            wp_send_json_error(array(
                'mess' => __('Folder name cannot be empty', 'easy-folders')
            ));
        }
    }

    /**
     * Save folder
     * @since 1.0.0
     * @param $request
     * @return JSON
    */
    public function saveFolder($request)
    {
        $id = sanitize_text_field($request->get_param('id'));

        $parent = sanitize_text_field($request->get_param('parent'));

        $name = sanitize_text_field($request->get_param('name'));

        $id = isset($id) ? sanitize_text_field($id) : '';

        $parent = isset($parent) ? intval(sanitize_text_field($parent)) : '';

        $name = isset($name) ? sanitize_text_field(wp_unslash($name)) : '';

        $folder = Easy_Folders_Media::getFolderDetail($id);

        if (is_numeric($id) && is_numeric($parent) && $name != '') {
            $update = Easy_Folders_Media::saveFolder($name, $parent, $id);

            if ($update === true) {
                $message = sprintf(__('"%1$s" renamed to "%2$s"', 'easy-folders'), $folder->name, $name);
                wp_send_json_success(
                    array(
                        'mess' => $message
                    )
                );
            } else {
                wp_send_json_error(array('mess' => sprintf(__('A folder named "%1$s" already exist', 'easy-folders'), $name)));
            }
        }

        wp_send_json_error();
    }

    /**
     * Delete items
     * @since 1.0.0
     * @param object $request
     * @return JSON
    */
    public function deleteItems($request)
    {
        $settings = (array) Easy_Folders_Settings::loadSettings();
        $translation = Easy_Folders_i18n::getTranslation();
        $trash = sanitize_text_field($request->get_param('trash'));
        $post_type = sanitize_text_field($request->get_param('post_type'));
        $activeFolder = sanitize_text_field($request->get_param('activeFolder'));
        $selectionItems = Easy_Folders_Helper::sanitizeArray($request->get_param('selectionItems'));
        $selectionItems = isset($selectionItems) ? Easy_Folders_Helper::sanitizeArray($selectionItems) : '';
        $folders = $attachments = [];
        if (count($selectionItems) > 0) {
            foreach ($selectionItems as $item) {
                $parms = explode("-", $item);
                if (isset($parms[0]) && isset($parms[1]) && $parms[0] == "folder") {
                    Easy_Folders_Media::destroyFolders($settings, $parms[1], $trash, $post_type);
                    array_push($folders, $parms[1]);
                } elseif (isset($parms[0]) && isset($parms[1]) && $parms[0] == "attachment") {
                    Easy_Folders_Media::deleteAttachment($settings, $parms[1], $trash, $activeFolder, $post_type);
                    array_push($attachments, $parms[1]);
                }
            }
            if ($trash) {
                if (count($selectionItems) > 1) {
                    $message = sprintf(__('%1$s items were moved to %2$s', 'easy-folders'), count($selectionItems), $translation['trash_bin']);
                } else {
                    $message = sprintf(__('%1$s item was moved to %2$s', 'easy-folders'), count($selectionItems), $translation['trash_bin']);
                }
            } else {
                if (count($selectionItems) > 1) {
                    $message = sprintf(__('%1$s items were deleted forever', 'easy-folders'), count($selectionItems));
                } else {
                    $message = sprintf(__('%1$s item was deleted forever', 'easy-folders'), count($selectionItems));
                }
            }

            wp_send_json_success(
                array(
                    'mess' => $message
                )
            );
        }
        wp_send_json_error(array(
            'mess' => __('Can not delete folder, please try again later', 'easy-folders')
        ));
    }

    

    

    

    

    

    /**
     * Move all selected folder/files to "Move to" folder
     * @since 1.0.0
     * @param object $request
     * @return JSON
    */
    public function moveToFolder($request)
    {
        $translation = Easy_Folders_i18n::getTranslation();
        $moveTo = sanitize_text_field($request->get_param('moveTo'));
        $selectionItems = $request->get_param('selectionItems');
        $selectionItems = isset($selectionItems) ? Easy_Folders_Helper::sanitizeArray($selectionItems) : '';
        $folders = $attachments = [];
        if (count($selectionItems) > 0) {
            if ($moveTo != '') {
                foreach ($selectionItems as $item) {
                    $parms = explode("-", $item);
                    if (isset($parms[0]) && isset($parms[1]) && $parms[0] == "folder") {
                        Easy_Folders_Media::pasteFolder($parms[1], $moveTo);
                        array_push($folders, $parms[1]);
                    } elseif (isset($parms[0]) && isset($parms[1]) && $parms[0] == "attachment") {
                        Easy_Folders_Media::attachFoldersToPosts($parms[1], $moveTo);
                        array_push($attachments, $parms[1]);
                    }
                }
                $folder_to = Easy_Folders_Media::getFolderDetail($moveTo);
                if (count($selectionItems) > 1) {
                    $message = sprintf(__('%1$s items were moved to "%2$s"', 'easy-folders'), count($selectionItems), $folder_to ? $folder_to->name : $translation['root']);
                } elseif (count($attachments) == 0) {
                    $folder_from = Easy_Folders_Media::getFolderDetail($folders[0]);
                    $message = sprintf(__('%1$s item was moved to "%2$s"', 'easy-folders'), $folder_from->name, $folder_to ? $folder_to->name : $translation['root']);
                } else {
                    $message = sprintf(__('%1$s item was moved to "%2$s"', 'easy-folders'), count($selectionItems), $folder_to ? $folder_to->name : $translation['root']);
                }
                wp_send_json_success(
                    array(
                        'mess' => $message
                    )
                );
            } else {
                wp_send_json_error(array(
                    'mess' => __('Some error occurred, please try again', 'easy-folders')
                ));
            }
        } else {
            wp_send_json_error(array('mess' => __('Some error occurred, please try again', 'easy-folders')));
        }
    }

    /**
     * Restore items
     * @since 1.0.0
     * @param object $request
     * @return JSON
    */
    public function restoreItems($request)
    {
        $selectionItems = $request->get_param('selectionItems');
        $selectionItems = isset($selectionItems) ? Easy_Folders_Helper::sanitizeArray($selectionItems) : '';
        $folders = $attachments = [];
        if (count($selectionItems) > 0) {
            foreach ($selectionItems as $item) {
                $parms = explode("-", $item);
                if (isset($parms[0]) && isset($parms[1]) && $parms[0] == "folder") {
                    array_push($folders, $parms[1]);
                    Easy_Folders_Media::restoreFolder($parms[1]);
                } elseif (isset($parms[0]) && isset($parms[1]) && $parms[0] == "attachment") {
                    $attachment = Easy_Folders_Media::getAttachmentDetail($parms[1]);
                    array_push($attachments, $parms[1]);
                    Easy_Folders_Media::restoreAttachment($parms[1]);
                }
            }
            if (count($selectionItems) > 1) {
                $message = sprintf(__('%1$s items were restored', 'easy-folders'), count($selectionItems));
            } elseif (count($attachments) == 0) {
                $folder = Easy_Folders_Media::getFolderDetail($folders[0]);
                $message = sprintf(__('"%1$s" was restored', 'easy-folders'), $folder->name);
            } else {
                $message = __('1 item was restored', 'easy-folders');
            }
            wp_send_json_success(
                array(
                    'mess' => $message
                )
            );
        } else {
            wp_send_json_error(array('mess' => __('Some error occurred, please try again', 'easy-folders')));
        }
    }

    /**
     * Empty bin
     * @since 1.0.0
     * @param $request
     * @return JSON
    */
    public function emptyBin($request)
    {
        $post_type = sanitize_text_field($request->get_param('post_type'));
        
        Easy_Folders_Media::emptyBin($post_type);

        wp_send_json_success(
            array(
                'mess' => __('Trash emptied successfully', 'easy-folders')
            )
        );
    }

    /**
     * Move to uncategorized
     * @since 1.0.0
     * @param $request
     * @return JSON
    */
    public function moveToUncategorized($request)
    {
        $translation = Easy_Folders_i18n::getTranslation();
        $selectionItems = $request->get_param('selectionItems');
        $selectionItems = isset($selectionItems) ? Easy_Folders_Helper::sanitizeArray($selectionItems) : '';
        $activeFolder = sanitize_text_field($request->get_param('activeFolder'));
        $activeFolder = isset($activeFolder) ? sanitize_text_field(wp_unslash($activeFolder)) : '';
        $attachments = $all_folders = [];
        if (count($selectionItems) > 0) {
            foreach ($selectionItems as $item) {
                $parms = explode("-", $item);
                if (isset($parms[0]) && isset($parms[1]) && ltrim($parms[0], '"') == "folder") {
                    $folders = array();
                    $folders = Easy_Folders_Media::getAllChildsOfFolder(rtrim($parms[1], '"'), $folders);
                    foreach ($folders as $folder) {
                        $attachment_ids = Easy_Folders_Media::getAttachmentsOfSelectedFolders([$folder]);
                        foreach ($attachment_ids as $attachment) {
                            Easy_Folders_Media::attachFoldersToPosts($attachment_ids, 0);
                            $attachments = array_merge($attachments, $attachment_ids);
                        }
                    }
                    array_push($all_folders, $parms[1]);
                } elseif (isset($parms[0]) && isset($parms[1]) && ltrim($parms[0], '"') == "attachment") {
                    Easy_Folders_Media::attachFoldersToPosts(rtrim($parms[1], '"'), 0);
                    array_push($attachments, $parms[1]);
                }
            }
            if (count($selectionItems) > 1) {
                $message = sprintf(__('%1$s items were moved to "%2$s"', 'easy-folders'), count($selectionItems), $translation['uncategorized']);
            } elseif (count($attachments) == 0) {
                $folder = Easy_Folders_Media::getFolderDetail($all_folders[0]);
                $message = sprintf(__('"%1$s" was moved to "%2$s"', 'easy-folders'), $folder->name, $translation['uncategorized']);
            } else {
                $message = sprintf(__('%1$s item was moved to "%2$s"', 'easy-folders'), count($selectionItems), $translation['uncategorized']);
            }
            wp_send_json_success(
                array(
                    'mess' => $message
                )
            );
        } else {
            wp_send_json_error(array('mess' => __('Some error occurred, please try again', 'easy-folders')));
        }
    }

    /**
     * Move to root [Only folders]
     * @since 1.0.0
     * @param $request
     * @return JSON
    */
    public function moveToRoot($request)
    {
        $translation = Easy_Folders_i18n::getTranslation();
        $selectionItems = $request->get_param('selectionItems');
        $selectionItems = isset($selectionItems) ? Easy_Folders_Helper::sanitizeArray($selectionItems) : '';
        $selectionItems =  (array)array_filter($selectionItems, function ($item) {
            return str_contains($item, 'folder-');
        });
        $activeFolder = $request->get_param('activeFolder');
        $activeFolder = isset($activeFolder) ? sanitize_text_field(wp_unslash($activeFolder)) : '';
        $folders = [];
        if (count($selectionItems) > 0) {
            foreach ($selectionItems as $item) {
                $parms = explode("-", $item);
                if (isset($parms[0]) && isset($parms[1]) && ltrim($parms[0], '"') == "folder") {
                    Easy_Folders_Media::pasteFolder(rtrim($parms[1], '"'), 0);
                    array_push($folders, $parms[1]);
                }
            }
            if (count($selectionItems) > 1) {
                $message = sprintf(__('%1$s items were moved to "%2$s"', 'easy-folders'), count($selectionItems), $translation['root']);
            } else {
                $folder = Easy_Folders_Media::getFolderDetail($folders[0]);
                $message = sprintf(__('"%1$s" was moved to "%2$s"', 'easy-folders'), $folder->name, $translation['root']);
            }
            wp_send_json_success(
                array(
                    'mess' => $message
                )
            );
        } else {
            wp_send_json_error(array('mess' => __('Please select item first', 'easy-folders')));
        }
    }

    /**
     * Fetch attachments
     * @since 1.0.0
     * @param $request
     * @return JSON
    */
    public function fetchAttachments($request)
    {
        $selectionItems = $request->get_param('selectionItems');

        $selectionItems = isset($selectionItems) ? Easy_Folders_Helper::sanitizeArray($selectionItems) : '';

        $attachments = [];

        if (count($selectionItems) > 0) {
            foreach ($selectionItems as $item) {
                $parms = explode("-", $item);
                if (isset($parms[0]) && isset($parms[1]) && $parms[0] == "folder") {
                    $folders = array();
                    $folders = Easy_Folders_Media::getAllChildsOfFolder(rtrim($parms[1], '"'), $folders);
                    foreach ($folders as $folder) {
                        $attachment_ids = Easy_Folders_Media::getAttachmentsOfSelectedFolders([$folder], true);
                        $attachments = array_merge($attachments, $attachment_ids);
                    }
                } elseif (isset($parms[0]) && isset($parms[1]) && $parms[0] == "attachment") {
                    $attachment = get_post($parms[1]);
                    if ($attachment) {
                        array_push($attachments, $attachment);
                    }
                }
            }

            wp_send_json_success(
                array(
                    'success' => true,
                    'attachments' => $attachments
                )
            );
        } else {
            wp_send_json_error(array('mess' => __('Some error occurred, please try again', 'easy-folders')));
        }
    }

    

    

    
}
