;(function ($) {
  'use strict'

  /**
   * All of the code for your admin-facing JavaScript source
   * should reside in this file.
   *
   * Note: It has been assumed you will write jQuery code here, so the
   * $ function reference has been prepared for usage within the scope
   * of this function.
   *
   * This enables you to define handlers, for when the DOM is ready:
   *
   * $(function() {
   *
   * });
   *
   * When the window is loaded:
   *
   * $( window ).load(function() {
   *
   * });
   *
   * ...and/or other possibilities.
   *
   * Ideally, it is not considered best practise to attach more than a
   * single DOM-ready or window-load handler for a particular page.
   * Although scripts in the WordPress core, Plugins and Themes may be
   * practising this, we should strive to set a better example in our own work.
   */
  //EasyFolders screens
  if (
    appLocalizer?.screen === 'upload.php' ||
    appLocalizer?.screen === 'toplevel_page_easyfolders' ||
    appLocalizer?.screen === 'easyfolders_page_easyfolders-pro'
  ) {
    $(
      '<div id="wp-load-more" class="wp-load-more initial-load"><svg class="spinit" viewBox="0 0 50 50"><circle class="path" cx="25" cy="25" r="20" fill="none" stroke-width="4"></circle></svg></div>'
    ).insertBefore('#wpbody')


    $('.update-nag').hide();

    //Hide all notices except EasyFolders
    $('#wpbody-content .easy-folders-notice, .notice').each(function () {
      if (!$(this).hasClass('easy-folders-notice')) {
        $(this).remove()
      }
    });

    //Hide permanently delete button
    let media_toolbar = setInterval(() => {
      if($('button.button.media-button.select-mode-toggle-button').length > 0) {
        $('button.button.media-button.select-mode-toggle-button').remove();
        $('.media-toolbar-secondary').append('<button type="button" class="button media-button button-primary easy-folders-custom-action bulk-delete" style="display:none" disabled>'+appLocalizer.i18n.delete+'</button><button type="button" class="button media-button button-primary bulk-restore" style="display:none" disabled>'+appLocalizer.i18n.restore+'</button><button type="button" class="button media-button apply empty-trash" disabled>'+appLocalizer.i18n.empty_trash+'</button><button type="button" class="button media-button select-mode-toggle-button">'+appLocalizer.i18n.bulk_select+'</button>');
        $('.media-toolbar .media-button.button-large[disabled=disabled]').remove();
        $('.media-toolbar-primary.search-form #media-search-input').remove();
        $('.media-toolbar-primary.search-form').append('<input type="search" id="easy-folder-media-search-input" class="search">');
        clearInterval(media_toolbar);
      }
    }, 10);

    //Media tool bar actions
    jQuery(document).on('click', 'button.button.media-button.select-mode-toggle-button', (e) => {
      const toolbar = jQuery('div.media-toolbar.wp-filter');
      const children = toolbar.find('.media-toolbar-secondary > *, .media-toolbar-primary > *');
      const controller = jQuery('button.button.media-button.select-mode-toggle-button');
      const activeFolder = Number(jQuery('[name=activeFolder]').val());
      if (jQuery('.media-frame').hasClass('mode-edit')) {
          children.not('.spinner, .media-button').hide();
          jQuery('.easy-folders-custom-action').show();
          controller.show();
          controller.text('Cancel');
          toolbar.addClass('media-toolbar-mode-select');
          toolbar.find('.delete-selected-button').removeClass('hidden');
          jQuery('.media-frame').removeClass('mode-edit');
          jQuery('.media-frame').addClass('mode-select');
          if(activeFolder === 2) {
            jQuery('.bulk-restore').show();
          } else {
            jQuery('.bulk-restore').hide();
          }
      } else {
          jQuery('div.attachments-browser.has-load-more.hide-sidebar.sidebar-for-errors').removeClass( 'fixed' );
          toolbar.css('width', '');
          controller.text('Bulk select');
          toolbar.removeClass('media-toolbar-mode-select');
          toolbar.find('.delete-selected-button').addClass('hidden');
          children.not('.media-button').show();
          jQuery('.easy-folders-custom-action').hide();
          jQuery('.media-frame').addClass('mode-edit');
          jQuery('.media-frame').removeClass('mode-select');
          jQuery('.bulk-restore').hide();
      }
    });

    //Disabled empty trash by default in list view
    $('#delete_all').prop('disabled', true);
    
    //Listen media grid response
    $( document ).ajaxComplete(function( event, xhr, settings ) {
      const response = $.parseJSON(xhr.responseText);
      $('.no-media').attr('data-attachments', response?.data?.length);
      $('.no-media').trigger('click');
    });
  }

  /********Notices********/

  const remove_element = function (el, timeout) {
    if (typeof timeout === 'undefined') {
      timeout = 100
    }
    el.fadeTo(timeout, 0, function () {
      el.slideUp(timeout, function () {
        el.remove()
      })
    })
  }

  //Handle Re-check button functionality
  $(document).on('click', '#easy-folders-revalidate-member', (e) => {
    e.preventDefault()
    const params = {
      action: 'update_api_status',
    }
    $.get(ajaxurl, params, function (r) {
      if (r.success) {
        window.location.href = appLocalizer.admin_url+'?page=easy-folders&action=api_update';
      }
    })
  });

  $(document).on('click', '#easy-folders-plugin-conflict-notice', (e) => {
    e.preventDefault()
    const params = {
      action: 'dismiss_notice',
      notice: $('#easy-folders-plugin-conflict-notice').attr('data-notice'),
    }
    const parent = $('#easy-folders-plugin-conflict-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  })

  $(document).on('click', '#easy-folders-account-connect-notice', (e) => {
    e.preventDefault()
    const params = {
      action: 'dismiss_notice',
      notice: $('#easy-folders-account-connect-notice').attr('data-notice'),
    }
    const parent = $('#easy-folders-account-connect-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  })

  $(document).on('click', '#easy-folders-initial-trial-upgrade-notice', (e) => {
    e.preventDefault()
    const params = {
      action: 'dismiss_notice',
      notice: $('#easy-folders-initial-trial-upgrade-notice').attr('data-notice'),
    }
    const parent = $('#easy-folders-initial-trial-upgrade-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  })
  
  $(document).on('click', '#easy-folders-account-payment-due-notice', (e) => {
    e.preventDefault()
    const params = {
      action: 'dismiss_notice',
      notice: $('#easy-folders-account-payment-due-notice').attr('data-notice'),
    }
    const parent = $('#easy-folders-account-payment-due-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  })

  $(document).on('click', '#easy-folders-upgrade-to-pro-notice', (e) => {
    e.preventDefault()
    const params = {
      action: 'dismiss_notice',
      notice: $('#easy-folders-upgrade-to-pro-notice').attr('data-notice'),
    }
    const parent = $('#easy-folders-upgrade-to-pro-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  })

  $(document).on('click', '#easy-folders-dismiss-usage-tracking-notice', (e) => {
    e.preventDefault()
    const params = {
      action: 'dismiss_notice',
      notice: $('#easy-folders-dismiss-usage-tracking-notice').attr('data-notice'),
    }
    const parent = $('#easy-folders-dismiss-usage-tracking-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  })

  $(document).on('click', '#easy-folders-toggle-usage-tracking-content', (e) => {
    if (
      $(
        '#easy-folders-dismiss-usage-tracking-notice-parent .easy-folders-permissions'
      ).hasClass('easy-folders-permissions--show')
    ) {
      $(
        '#easy-folders-dismiss-usage-tracking-notice-parent .easy-folders-permissions'
      ).removeClass('easy-folders-permissions--show')
    } else {
      $(
        '#easy-folders-dismiss-usage-tracking-notice-parent .easy-folders-permissions'
      ).addClass('easy-folders-permissions--show')
    }
  })

  $(document).on('click', '#easy-folders-usage-tracking_submit', (e) => {
    e.preventDefault()
    const params = {
      action: 'save_usage_tracking',
    }
    const parent = $('#easy-folders-dismiss-usage-tracking-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  });

  $(document).on('click', '#easy-folders-account-domain-mismatch-notice', (e) => {
    e.preventDefault()
    const params = {
      action: 'dismiss_notice',
      notice: $('#easy-folders-account-domain-mismatch-notice').attr('data-notice'),
    }
    const parent = $('#easy-folders-account-domain-mismatch-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  })

  $(document).on('click', '#easy-folders-rate-notice', (e) => {
    e.preventDefault()
    const params = {
      action: 'dismiss_notice',
      notice: $('#easy-folders-rate-notice').attr('data-notice'),
    }
    const parent = $('#easy-folders-rate-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  });

  $(document).on('click', '#easy-folders-rate-notice-already-done', (e) => {
    e.preventDefault()
    const params = {
      action: 'dismiss_notice',
      notice: $('#easy-folders-rate-notice-already-done').attr('data-notice'),
    }
    const parent = $('#easy-folders-rate-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  });

  $(document).on('click', '#easy-folders-free-to-pro-plugin-conversion-notice', (e) => {
    e.preventDefault()
    const params = {
      delete: true,
      action: 'dismiss_notice',
      notice: $('#easy-folders-free-to-pro-plugin-conversion-notice').attr('data-notice'),
    }
    const parent = $('#easy-folders-free-to-pro-plugin-conversion-notice-parent')
    parent.addClass('loading-notice')
    $.post(ajaxurl, params, function (r) {
      parent.removeClass('loading-notice').addClass('loaded-notice')
      remove_element(parent, 200)
    })
  })

})(jQuery)
