<?php

/**
 * Class that contain all about Easy Folders subscription
 */
class Easy_Folders_Subscription
{    
    /**
     * Detect account subscription
     * @since 1.0.0
     * @return boolean
     */
    public static function is_pro($settings = array())
    {
        if(empty($settings)) {
            $settings = Easy_Folders_Settings::loadSettings();
        }
        
        if(self::is_active($settings) && (isset($settings['site_status']['is_free']) && $settings['site_status']['is_free'] == 0) && (isset($settings['site_status']['website']['type']) && $settings['site_status']['website']['type'] == "pro")) {
            return true;
        }

        return false;
    }
    
    /**
     * Verify account is connected
     * @since 1.0.0
     * @param $settings
     * @return boolean
     */
    public static function is_active($settings = array())
    {
        if(empty($settings)) {
            $settings = Easy_Folders_Settings::loadSettings();
        }

        if($settings['license_key']) {
            return true;
        }

        return false;
    }

    

    /**
     * Process site status.
     * @since 1.0.0
     * @param array|WP_Error $response
     * @return stdClass|WP_Error
     */
    public function processSiteStatus($response)
    {
        if (is_wp_error($response)) {
            return $response;
        }

        $status = json_decode($response['body']);

        if (is_null($status) || wp_remote_retrieve_response_code($response) === 429) {
            wp_send_json_error(
                array(
                    'message' =>  __('Too many requests, please try again in a moment', 'easy-folders')
                ),
                200
            );
        }

        return $status;
    }
}
