<?php
class Easy_Folders_Tree
{

    private static $efs_colors = 'efs_colors';

    /**
     * Folder count
     * @since 1.0.0
     * @param $folder_id
     * @param $lang
     * @param $post_type
     * @return mixed
    */
    public static function getFolderCount($folder_id, $lang = null, $post_type = 'attachment')
    {
        global $wpdb;

        if ($folder_id == 1) {
            $select = "SELECT COUNT(*) FROM {$wpdb->prefix}efs WHERE starred = 1";
            return (int)$wpdb->get_var($select);
        } else {
            $select = "SELECT COUNT(*) FROM {$wpdb->posts} as posts WHERE ";

            $where = array("post_type = '".$post_type."'");

            // For specific folder
            if ($folder_id > 0) {
                $post__in = $wpdb->get_col("SELECT `attachment_id` FROM {$wpdb->prefix}efs_attachment_folder WHERE `folder_id` = " . (int)$folder_id . " AND deleted_at IS NULL");
                if (count($post__in) == 0) {
                    $post__in = array(0);
                }
                $where[] = "(ID IN (" . implode(', ', $post__in) . "))";
            } elseif ($folder_id == 0) {
                return 0; //return 0 if this is uncategorized folder
            }

            $where = apply_filters('easyfolders_extend_fetch_count_where_query', $where);

            $query = $select . implode(' AND ', $where);

            $query = $query.' '.Easy_Folders_Media::extendPostTypeQuery($post_type, null);

            return (int)$wpdb->get_var($query);
        }
    }

    /**
     * Get all data
     * @since 1.0.0
     * @param $order_by
     * @param $flat
     * @param $level
     * @param $show_level
     * @param $trash
     * @param $post_type
     * @return array
    */
    public static function getAllData($order_by = null, $flat = false, $level = 0, $show_level = false, $trash = false, $all = false, $post_type = 'attachment')
    {
        $folders_from_db = Easy_Folders_Media::getAllFolders('*', null, $order_by, $trash, $all, $post_type);

        $default_folders = array();

        $tree = self::getTreeHirerchy($folders_from_db, 0, $default_folders, $flat, $level, $show_level);

        return $tree;
    }

    /**
     * Folders tree hierarchy
     * @since 1.0.0
     * @param $data
     * @param $parent
     * @param $default
     * @param $flat
     * @param $level
     * @param $show_level
     * @return array
    */
    private static function getTreeHirerchy($data, $parent = 0, $default = null,  $flat = false, $level = 0, $show_level = false)
    {
        global $wpdb;

        $tree = is_null($default) ? array() : $default;

        foreach ($data as $k => $v) {
            if ($v->parent == $parent) {
                $children = self::getTreeHirerchy($data, $v->id, null, $flat, $level + 1, $show_level);

                $color = null;
                
                //Find color 
                if($v->color) {
                    $color = $wpdb->get_row("SELECT * FROM " . self::getTable(self::$efs_colors) . " WHERE `id` = '" . (int)$v->color . "'");
                }
                
                $f = array(
                    'id' => (int)$v->id,
                    'text' => $show_level ? str_repeat('-', $level) . $v->name : $v->name,
                    'parent' => (int)$parent,
                    'color' => isset($color) && $color ? $color->color : '',
                    'starred' => $v->starred,
                    'type' => $v->type,
                    'shortcut' => $v->shortcut,
                    'li_attr' => array("data-count" => 0, "data-parent" => (int)$parent),
                    'count' => 0
                );

                if ($flat === true) {
                    $tree[] = $f;
                    foreach ($children as $k2 => $v2) {
                        $tree[] = $v2;
                    }
                } else {
                    $f['children'] = $children;
                    $tree[] = $f;
                }
            }
        }
        
        return $tree;
    }

    /**
     * Get all folders with count
     * @since 1.0.0
     * @param $lang
     * @param $post_type
     * @return array
    */
    public static function getFoldersCount($lang = null, $post_type = 'attachment')
    {
        global $wpdb;
        $query = $wpdb->prepare("SELECT efsa.folder_id, count(efsa.attachment_id) as count FROM {$wpdb->prefix}efs_attachment_folder as efsa 
        INNER JOIN {$wpdb->prefix}efs as efs ON efs.id = efsa.folder_id 
        INNER JOIN {$wpdb->posts} as posts ON efsa.attachment_id = posts.ID  
        WHERE posts.post_type = '".$post_type."'
        ".Easy_Folders_Media::extendPostTypeQuery($post_type, 'posts')."
        AND posts.post_status != 'trash'
        AND efs.created_by = %d 
        AND efsa.deleted_at IS NULL
        GROUP BY efsa.folder_id", apply_filters('easyfolders_current_user_id', '0'));
        $query = apply_filters('efs_all_folders_and_count', $query, $lang);
        $results = $wpdb->get_results($query);
        $return = array();
        if (is_array($results)) {
            foreach ($results as $k => $v) {
                $return[$v->folder_id] = $v->count;
            }
        }
        return $return;
    }
    
    /**
     * All folder ids
     * @since 1.0.0
     * @param $order_by
     * @return array
    */
    public static function getAllFoldersId($order_by = null)
    {
        return Easy_Folders_Media::getAllFolders('id, name', null, $order_by);
    }

    /**
     * Root to folder path
     * @since 1.0.0
     * @param $children
     * @param $folderId
     * @param $node_path_storage
     * @param $node_path
     * @param $path
     * @return array
    */
    public static function getRootToFolderPath($children, $folderId, &$node_path_storage, $node_path, &$path)
    {
        $original_node_path = $node_path;
        foreach ($children as $child) {
            $node_path = $original_node_path . '/' . $child['text'];
            array_push($node_path_storage, $node_path);
            if ($child['id'] == $folderId) {
                $find = array_filter($node_path_storage, function ($row) use ($node_path) {
                    return $row == $node_path;
                });
                if (!empty($find)) {
                    $path = array_values($find)[0];
                    return $path;
                }
            } else if (!empty($child['children'])) {
                self::getRootToFolderPath($child['children'], $folderId, $node_path_storage, $node_path, $path);
            }
        }
    }

    /**
     * Get folder children's ids
     * @since 1.0.0
     * @param $tree
     * @param $folders
     * @return array
    */
    public static function getFolderChildrensIds($tree, &$folders = array())
    {
        foreach ($tree as $row) {
            array_push($folders, $row['id']);
            if (isset($row['children']) && count($row['children']) > 0) {
                self::getFolderChildrensIds($row['children'], $folders);
            }
        }

        return $folders;
    }

    /**
     * Recursive array search 
     * @since 1.0.0
     * @param $array
     * @param $value
     * @return mixed
    */
    public static function recursiveArraySearch($array, $value)
    {
        foreach ($array as $key => $item) {
            if ($item['id'] == $value) {
                return $item;
            } else {
                if (isset($item['children']) && count($item['children']) > 0) {
                    $keyFound = self::recursiveArraySearch($item['children'], $value);
                    if ($keyFound != false) {
                        return $keyFound;
                    }
                }
            }
        }
        return false;
    }

    /**
     * Get table
     * @since 1.0.0
     * @param $table
     * @return string
    */
    private static function getTable($table)
    {
        global $wpdb;
        return $wpdb->prefix . $table;
    }
}
