<?php
trait Easy_Folders_General_Hooks {

    /**
     * Media routes / Gutenberg routes
     * @since 1.0.0
     * @return void
    */
    public function media_routes()
	{
		//Media routes
		$this->media_controller->routes();

		//Media library hooks [Need to register after routes registrations because these are using in route base implementations]
		$this->wp_media_library = new Easy_Folders_Media_Hook($this->settings);
		$this->wp_media_library->my_hooks();

		
	}

	/**
     * When add attachment
     * @since 1.0.0
	 	 * @param $post_id
     * @return void
    */
	public function addAttachment($post_id)
	{
		$this->media_controller->addAttachment($post_id);
	}

	/**
     * When delete attachment
     * @since 1.0.0
	 	 * @param $post_id
     * @return void
    */
	public function deleteAttachment($post_id) {}
	
    /**
     * Set attachment Args
     * @since 1.0.0
	   * @param $query
     * @return array
    */
	public function setQueryAttachmentsArgs($query)
	{
		return $this->media_controller->setQueryAttachmentsArgs($query);
	}

	/**
     * Filters all query clauses at once, for convenience.
     * @since 1.0.0
	   * @param $clauses
	   * @param $query
     * @return array
    */
	public function customizedPostsClauses($clauses, $query)
	{
		return $this->media_controller->customizedPostsClauses($clauses, $query);
	}

	/**
     * Wordpress admin menus
     * @since 1.0.0
     * @return void
    */
    public function settingMenus()
	{
		global $submenu;

		$role = Easy_Folders_Helper::getCurrentUserRole();

		if(!$this->settings['access_setting'] || is_super_admin() || ($this->settings['access_setting'] && $role == "administrator")) {
			
			if(get_option('easy-folders-install-hide')) {
				$this->pages['easyfolders'] = new Easy_Folders_Menus("easyfolders", __('Easy Folders', 'easy-folders'));
				$this->pages['easyfolders-settings'] = new Easy_Folders_Menus("easyfolders", __('Settings', 'easy-folders'), "easyfolders", "easy-folders-settings");
			}
	
			if(!get_option('easy-folders-install-hide')) {
				$this->pages['easyfolders'] = new Easy_Folders_Menus("easyfolders", __('Easy Folders', 'easy-folders'));
				$this->pages['easyfolders-install'] = new Easy_Folders_Menus("easyfolders", __('Install', 'easy-folders'), "easyfolders", "easy-folders-install");
			}
			
			//Show pro menu
			if(!Easy_Folders_Subscription::is_pro($this->settings)) {
				$this->pages['easyfolders-pro'] = new Easy_Folders_Menus("easyfolders-pro", '<span style="color: #00ffbf;">' . __('Easy Folders Pro', 'easy-folders') . '<i class="dashicons dashicons-star-filled" style="font-size:12px;vertical-align:-2px;height:10px;"></i></span>', "easyfolders", "easy-folders-pro");
			}
	
			$submenu['easyfolders'][] = [ esc_html__( 'Help &amp; Support', 'easy-folders' ) . '<i class="dashicons dashicons-external" style="font-size:12px;vertical-align:-2px;height:10px;"></i>', 'level_1', EASY_FOLDERS_GO_URL.'/support' ];
	
			//screens
			if (count($this->pages) > 0) {
				foreach ($this->pages as $key => $page) {
					$GLOBALS[$page->page_id] = $page->page_id;
				}
			}
		}
	}

	/**
	 * adminHead
	 * @since 1.0.0
	 * @return void
	 */
	public function adminHead()
	{
		echo '
		<script type="text/javascript">
			// Open RM KB menu link in the new tab.
			jQuery( document ).ready( function( $ ) {
				$( "ul#adminmenu a[href$=\''.esc_url(EASY_FOLDERS_GO_URL).'/support\']" ).attr( "target", "_blank" );
			} );
		</script>
		';
	}
	
	/**
     * Settings routes
     * @since 1.0.0
     * @return void
    */
	public function settings_routes()
	{
		$this->import_media_plugin_controller->routes();

		$this->settings_controller->routes();
	}

	/**
     * Export Easy Folders content
     * @since 1.0.0
     * @return void
    */
	public function exportContent()
	{
		$this->import_media_plugin_controller->export();
	}

	/**
     * Fires before the upload interface loads in WP admin
     * @since 1.0.0
     * @return void
    */
	public function upload_ui_media_new()
	{
		global $pagenow;

		if(isset($this->post_type) && $this->post_type && $this->settings[$this->post_type] && $this->post_type == 'attachment' && $pagenow != 'media-new.php') {
			echo '
			<p class="upload-instructions drop-instructions">'.__('or', 'easy-folders').'</p>
			<button type="button" class="button easy-folders--action--folder-upload" style="position: relative; z-index: 1;">'.__('Select Folder', 'easy-folders').'</button><br>';
		} else if($pagenow == 'media-new.php') {
			if ( is_admin() && function_exists('get_current_screen') && get_current_screen() && get_current_screen()->base === 'media' ) {
				echo '
				<p>' . esc_attr(__("Optional: Assign a folder to your uploaded file(s):", 'easy-folders')) . '</p>
				<div id="wp-media-new-screen-select-folders" class="mt-8"></div><br>';
			}
		}
		
		// Show folders drop down in Wp media modal
		$this->loadTemplate('widgets/list-folders');
	}

	/**
     * Before upload media
     * @since 1.0.0
	   * @param $file
     * @return mixed
    */
	public function uploadPreFilter($file)
	{
		if(function_exists('get_current_screen') && get_current_screen() && get_current_screen()->base === 'async-upload') {

			if(isset($_REQUEST['efs']) && $_REQUEST['efs'] != '') {

				$result = $this->validate_file( $file['name'] );
	
				if ( is_wp_error( $result ) ) {
					$file['error'] = $result->get_error_message();
				}
		
				$file_size = @filesize($file['tmp_name']);
		
				$max_file_upload = wp_max_upload_size();
		
				if(isset($file_size) && $file_size > 0 && isset($max_file_upload) && $max_file_upload > 0 && $file_size > $max_file_upload) {
					$file['error'] = __("You have reached your maximum file upload size limit", 'easy-folders');
				}
		
				$file['efs'] = isset($_REQUEST['efs']) ? sanitize_text_field($_REQUEST['efs']) : -1;
		
				//Prevent to upload duplicate in case of queue process
				$upload_ids = get_transient('upload-ids');
		
				if(isset($_REQUEST['hash']) && $_REQUEST['hash']) {
					if(!empty($upload_ids)) {
						if(in_array($_REQUEST['hash'], $upload_ids)) {
							wp_send_json_success(array(
								'message' => __('Already uploaded', 'easy-folders')
							));
						} else {
							$upload_ids[] = sanitize_text_field($_REQUEST['hash']);
							set_transient('upload-ids', $upload_ids, 3600 );
						}
					} else {
						$upload_ids = [sanitize_text_field($_REQUEST['hash'])];
						set_transient('upload-ids', $upload_ids, 3600 );
					}
				}
			}
			
		}

		return $file;
	}

	/**
	 * Validate File
	 * @since 1.0.0
	 * @param string $file_path
	 * @param array $file_extensions Optional
	 * @return bool|\WP_Error
	 *
	*/
	private function validate_file( $file_path, $file_extensions = [] ) {

		$file_extension = pathinfo( $file_path, PATHINFO_EXTENSION );

		$allowed_file_extensions = $this->get_allowed_file_extensions();

		if ( $file_extensions ) {
			$allowed_file_extensions = array_intersect( $allowed_file_extensions, $file_extensions );
		}

		$file_extensions = [];

		if(count($allowed_file_extensions) > 0) {

			foreach($allowed_file_extensions as $file_ext) {

				if(str_contains($file_ext, '|')) {

					foreach(explode("|", $file_ext) as $ext) {

						$file_extensions[] = strtolower(trim($ext));

					}

				} else {
					$file_extensions[] = strtolower(trim($file_ext));
				}
			}

		}

		// Check if the file type (extension) is in the allowed extensions list. If it is a non-standard file type (not
		// enabled by default in WordPress) and unfiltered file uploads are not enabled, it will not be in the allowed
		// file extensions list.
		if ( ! in_array( $file_extension, $file_extensions ) ) {
			return new \WP_Error( 403, __('Uploading this file type is not allowed', 'easy-folders'));
		}

		return true;
	}

	/**
	 * Get Allowed File Extensions
	 * Retrieve an array containing the list of file extensions allowed for upload.
	 * @since 1.0.0
	 * @return array file extension/s
	 */
	private function get_allowed_file_extensions() {
		
		if ( ! $this->allowed_file_extensions ) {
			$this->allowed_file_extensions = array_keys( get_allowed_mime_types() );
		}

		return $this->allowed_file_extensions;
	}

    /**
     * Set current page id
     * @since 1.0.0
     * @return int
    */
	public function getPageId()
	{
		if (null == $this->pageId) {
			$this->pageId = EASY_FOLDERS_VERSION . '-settings';
		}

		return $this->pageId;
	}

	/**
     * Fires as an admin screen or script is being initialized.
     * @since 1.0.0
     * @return void
    */
	public function admin_init()
	{
		//Media library hooks
		$this->wp_media_library = new Easy_Folders_Media_Hook($this->settings);
		$this->wp_media_library->wp_hooks(); 

		//Check schedules
		self::check_schedules();
	}

	/**
     * Fires after WordPress has finished loading but before any headers are sent.
     * @since 1.0.0
     * @return void
    */
	public function init()
	{
		
	}

	/**
     * Load template
     * @since 1.0.0
	   * @param $template
	   * @param $lib_params
     * @return void
    */
    public function loadTemplate($template, $lib_params = array())
    {
        ob_start();
        $params = $lib_params;
        include_once EASY_FOLDERS_PLUGIN_DIR . 'admin/partials/' . $template . ".php";
        $template = ob_get_contents();
        ob_end_clean();
        echo wp_kses_post($template);
    }

	/**
	 * Redirect to installer page if activating plugin first time
	 * @since 1.0.0
	 * @return void
	 */
	public function redirect_after_installation()
    {
		if (get_option('easy-folders-activation-redirect', false)) {
			delete_option('easy-folders-activation-redirect');
			wp_redirect( admin_url( 'admin.php?page=easyfolders' ) );
		}
	}

	/**
	 * Save usage tracking.
	 * @since 1.0.0
	 * @return void
	 */
	public function save_usage_tracking() {
		update_option(EASY_FOLDERS_PREFIX.'usage_tracking', 1);
	}

	/**
	 * Get table
	 * @since 1.0.0
	 * @param $table
	 * @return void
	 */
    private static function getTable($table)
    {
        global $wpdb;
        return $wpdb->prefix . $table;
    }
	
	/**
	 * Fires once activated plugins have loaded
	 * @since 1.0.0
	 * @return void
	 */
	public function plugins_loaded() {

		//Manage plugin updates
		$this->plugin_update = new Easy_Folders_Plugin_Update($this->settings);
		$this->plugin_update->init();

		
	}

	/**
	 * Extend posts query for posts count
	 * @since 1.0.0
	 * @param $where
	 * @return array
	 */
	public function extendFetchCountWhereQuery($where)
    {
        global $wpdb;
        
		if (function_exists('picu_exclude_collection_images_from_library')) {
            $where[] = " posts.post_parent NOT IN (SELECT {$wpdb->posts}.ID FROM {$wpdb->posts} WHERE {$wpdb->posts}.post_type = 'picu_collection') ";
        }
		
        if (function_exists('_is_elementor_installed')) {
            $where[] = " posts.ID NOT IN (SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key = '_elementor_is_screenshot') ";
        }

        return $where;
    }

	/**
	 * Filters the array of row meta for each plugin in the Plugins list table.
	 * @since 1.0.0
	 * @param $links
	 * @param $file
	 * @return array
	 */
	public function plugin_row_meta($links, $file)
    {
		if ( strpos( $file, 'easy-folders.php' ) !== false ) {
			
			$links[] = '<a href="'.EASY_FOLDERS_GO_URL.'/help" target="_blank">'. __("Docs", "easy-folders") .'</a>';
			
			$links[] = '<a href="'.EASY_FOLDERS_GO_URL.'/support" target="_blank">'. __("Support", "easy-folders") .'</a>';
		}

		return $links;
	}

	/**
	 * Filters the list of action links displayed for a specific plugin in the Plugins list table.
	 * @since 1.0.0
	 * @param $links
	 * @return array
	 */
	public function plugin_action_links($links)
    {
		$settingsLinks = array(
			'<a href="' . admin_url( 'admin.php?page=easyfolders-settings' ) . '">'. __("Settings", "easy-folders") .'</a>',
		);

		//Show for only Free
		$go_pro = __( 'Start free trial', 'easy-folders' );

		if((is_plugin_active( 'easy-folders/easy-folders.php' ) && EASY_FOLDERS_BASENAME == 'easy-folders/easy-folders.php') || !Easy_Folders_Subscription::is_pro($this->settings)) {
			$links[] = '<a target="_blank" href="'.EASY_FOLDERS_GO_URL.'/pricing" style="color: #cf37e6;font-weight: 600;">' . $go_pro . '</a>';
		}
		
		return array_merge( $settingsLinks, $links );
	}
}
?>
