<?php

/**
 * Easy Folders
 *
 * Easy folders is the best WordPress media plugin to organize media library into folders,
 *
 * @link              https://ripebits.com
 * @since             1.0.0
 * @package           EasyFolders
 *
 * @wordpress-plugin
 * Plugin Name:       Easy Folders
 * Plugin URI:        http://wordpress.org/plugins/easy-folders/
 * Description:       A single powerful and easy-to-use plugin to take care of all media needs. Organize your media files into folders.
 * Version:           1.0.1
 * Author:            Media Library Folders - RipeBits
 * Author URI:        https://ripebits.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       easy-folders
 * Domain Path:       /languages/
 */

 /*
This plugin was originally developed by RipeBits Team (https://ripebits.com).

Copyright 2023 RipeBits (https://ripebits.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License (Version 2 - GPLv2) as published by
the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// If this file is called directly, abort.
if (!defined('WPINC')) {
	die;
}

if ( ! defined( 'EASY_FOLDERS_VERSION' ) ) {
	define('EASY_FOLDERS_VERSION', '1.0.1');
}

//Rest api routes prefix
if ( ! defined( 'EASY_FOLDERS_REST_API_PREFIX' ) ) {
	define('EASY_FOLDERS_REST_API_PREFIX', 'ripebits/v1');
}

if ( ! defined( 'EASY_FOLDERS_BASENAME' ) ) {
	define( 'EASY_FOLDERS_BASENAME', plugin_basename( __FILE__ ) );
}

if (!defined('EASY_FOLDERS_UPLOAD_DIR')) {
	define('EASY_FOLDERS_UPLOAD_DIR', 'easy-folders-uploads');
}

if (!defined('EASY_FOLDERS_PLUGIN_URL')) {
	define('EASY_FOLDERS_PLUGIN_URL', plugin_dir_url(__FILE__));
}

if (!defined('EASY_FOLDERS_PLUGIN_DIR')) {
	define('EASY_FOLDERS_PLUGIN_DIR', plugin_dir_path(__FILE__));
}

if ( ! defined( 'EASY_FOLDERS_PLUGIN_FILE' ) ) {
	define( 'EASY_FOLDERS_PLUGIN_FILE', __FILE__ );
}

if (!defined('EASY_FOLDERS_PREFIX')) {
	define('EASY_FOLDERS_PREFIX', 'easy-folders-');
}

if (!defined('EASY_FOLDERS_PLUGIN_NAME')) {
	define('EASY_FOLDERS_PLUGIN_NAME', 'easy-folders');
}

if (!defined('EASY_FOLDERS_LOCALIZATION_PREFIX')) {
	define('EASY_FOLDERS_LOCALIZATION_PREFIX', 'easy-folders');
}

if (!defined('EASY_FOLDERS_CACHE_PREFIX')) {
	define('EASY_FOLDERS_CACHE_PREFIX', 'easy-folders');
}

if (!defined('EASY_FOLDERS_UA')) {
	define('EASY_FOLDERS_UA', 'WP EasyFolders/' . EASY_FOLDERS_VERSION . '; ' . network_home_url());
}

if (!defined('EASY_FOLDERS_API_URL')) {
	define('EASY_FOLDERS_API_URL', 'https://api.ripebits.com');
}

if (!defined('EASY_FOLDERS_GO_URL')) {
	define('EASY_FOLDERS_GO_URL', 'https://go.ripebits.com/easy-folders');
}

if ( ! function_exists( 'is_plugin_active' ) ) {
	include_once ABSPATH . 'wp-admin/includes/plugin.php';
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-easy-folders-activator.php
 * @since 1.0.0
 */
if ( ! function_exists( 'easyfolders_activate' ) ) {
	function easyfolders_activate()
	{
		require_once plugin_dir_path(__FILE__) . 'includes/class-easy-folders-activator.php';
		Easy_Folders_Activator::activate();
	}
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-easy-folders-deactivator.php
 * @since 1.0.0
 */
if ( ! function_exists( 'easyfolders_deactivate' ) ) {
	function easyfolders_deactivate()
	{
		require_once plugin_dir_path(__FILE__) . 'includes/class-easy-folders-deactivator.php';
		Easy_Folders_Deactivator::deactivate();
	}
}

/**
 * The code that runs during plugin uninstallation.
 * This action is documented in includes/class-easy-folders-uninstall.php
 * @since 1.0.0
 */
if ( ! function_exists( 'easyfolders_uninstall' ) ) {
	function easyfolders_uninstall()
	{
		require_once plugin_dir_path(__FILE__) . 'includes/class-easy-folders-uninstall.php';
		Easy_Folders_Uninstall::uninstall();
	}
}

/**
 * If we are activating a version, while having another present and activated.
 * Leave in the Pro version, if it is available.
 * @since 1.0.0
 */

if ( EASY_FOLDERS_BASENAME !== plugin_basename( __FILE__ ) ) {

	$pro = false;

	if ( file_exists( WP_PLUGIN_DIR . '/easy-folders-pro/easy-folders.php' ) ) {
		$pro = true;
	}

	if ( is_plugin_active( 'easy-folders-pro/easy-folders.php' ) ) {

		deactivate_plugins( plugin_basename( __FILE__ ) );

		return;

	} elseif ( $pro && is_plugin_active( EASY_FOLDERS_BASENAME ) ) {

		update_option( EASY_FOLDERS_PREFIX . 'free-to-pro-plugin-conversion-notice', 1 );

		deactivate_plugins( EASY_FOLDERS_BASENAME );

		// If Activating process of plugin
		if ( defined( 'WP_SANDBOX_SCRAPING' ) && WP_SANDBOX_SCRAPING ) {
			return;
		}
		
		activate_plugin( plugin_basename( __FILE__ ) );
	}
	
}

register_activation_hook(__FILE__, 'easyfolders_activate');

register_deactivation_hook(__FILE__, 'easyfolders_deactivate');

register_uninstall_hook(__FILE__, 'easyfolders_uninstall');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 * @since 1.0.0
 */
require plugin_dir_path(__FILE__) . 'includes/class-easy-folders.php';

// Try and include our autoloader.
if ( is_readable( __DIR__ . '/vendor/autoload.php' ) ) {
	require __DIR__ . '/vendor/autoload.php';
}

/**
 * Begins execution of the plugin.
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 * @since    1.0.0
 */
if ( ! function_exists( 'easyfolders_start' ) ) {
	function easyfolders_start()
	{
		$plugin = new Easy_Folders();
		$plugin->run();
	}
}

easyfolders_start();
