<?php

/**
 * Fired during plugin activation
 * @link       https://ripebits.com
 * @since      1.0.0
 * @package    EasyFolders
 * @subpackage EasyFolders/includes
 */

/**
 * Fired during plugin activation.
 * This class defines all code necessary to run during the plugin's activation.
 * @since      1.0.0
 * @package    EasyFolders
 * @subpackage EasyFolders/includes
 */
class Easy_Folders_Activator
{

	/**
	 * Fired during plugin activation.
	 * @since 1.0.0
	 * @return void
	 */
	public static function activate()
	{
		//Create DB Structure
		Easy_Folders_Helper::createDbStructure();

		//Default settings
		Easy_Folders_Helper::resetDefaultSettings(true);

		//Reset default colors
		Easy_Folders_Settings::resetDefaultColors();
		
		//Redirect to installer page if activating plugin first time
		if(!get_option('easy-folders-install-hide')) {
			add_option('easy-folders-activation-redirect', true);
		}

		//Account activation time
		Easy_Folders_Helper::addOrUpdateOption(EASY_FOLDERS_PREFIX . 'account-activation-timestamp', time());

		$location_info = Easy_Folders_Helper::getLocationInfoByIp();

		//User activation country code
		Easy_Folders_Helper::addOrUpdateOption(EASY_FOLDERS_PREFIX . 'activation-country-code', $location_info['country']);
		
		//Save usage tracking
		Easy_Folders_Settings::saveUsageTracking(['current_status' => 'Active']);

		//Hide rating modal/notice [Will active after a month by cron job]
		Easy_Folders_Helper::addOrUpdateOption(EASY_FOLDERS_PREFIX . 'rating-hide', 1);
		Easy_Folders_Helper::addOrUpdateOption(EASY_FOLDERS_PREFIX . 'rate-notice-hide', 1);

		//Hide it when initial activation of plugin
		Easy_Folders_Helper::addOrUpdateOption(EASY_FOLDERS_PREFIX . 'upgrade-to-pro-notice', 1);

		$settings = Easy_Folders_Settings::loadSettings();

		

		//Current user who installing plugin
		Easy_Folders_Helper::addOrUpdateOption(EASY_FOLDERS_PREFIX . 'activating_user', get_current_user_id());
	}
}
