<?php

/**
 * Define the internationalization functionality
 * Loads and defines the internationalization files for this plugin
 * so that it is ready for translation.
 * @link       https://ripebits.com
 * @since      1.0.0
 * @package    EasyFolders
 * @subpackage EasyFolders/includes
 */

/**
 * Define the internationalization functionality.
 * Loads and defines the internationalization files for this plugin
 * so that it is ready for translation.
 * @since      1.0.0
 * @package    EasyFolders
 * @subpackage EasyFolders/includes
 */
class Easy_Folders_i18n {

	/**
	 * Load the plugin text domain for translation.
	 * @since    1.0.0
	 * @return void
	 */
	public function load_plugin_textdomain() {

		if (function_exists('determine_locale')) {
            $locale = determine_locale();
        } else {
            $locale = is_admin() ? get_user_locale() : get_locale();
        }
		unload_textdomain('easy-folders');
		load_textdomain('easy-folders', EASY_FOLDERS_PLUGIN_DIR . '/languages/' . $locale . '.mo');
		load_plugin_textdomain('easy-folders', false, EASY_FOLDERS_PLUGIN_DIR . '/languages/');
	}
	
	/**
	 * getTranslation
	 * @since    1.0.0
	 * @return array
	 */
	public static function getTranslation()
    {
		$upgrade_now = __('Start a free trial', 'easy-folders');
		$upgrade_to_pro = __('Start a free trial', 'easy-folders');
		$unlock_new_features_sub = __('To use Easy Folders with %s, please upgrade to a PRO plan. <a href="%s" target={"_blank"}>Click here to start a free trial</a>.', 'easy-folders');
		$hellobar_upgrade_to_pro =  __('You\'re using Easy Folders Free, to unlock more features, consider upgrading to a Pro plan. <a href="%s" target={"_blank"}>Click here to start a free trial</a>&#160;<b>&#8594;</b>', 'easy-folders');
		$hero_section_description_one = sprintf(__('Start a free trial to unlock all the features of the Media library.', 'easy-folders'));

		$translation = array(
			'upgrade_now'		=> $upgrade_now,
			'unsaved_changes'		=> __('Unsaved changes', 'easy-folders'),
			'save'		=> __('Save', 'easy-folders'),
			'discard'		=> __('Discard', 'easy-folders'),
			'toggle'		=> __('Toggle', 'easy-folders'),
			'all'		=> __('All', 'easy-folders'),
			'none'		=> __('None', 'easy-folders'),
			'default'		=> __('Default', 'easy-folders'),
			'custom'		=> __('Custom', 'easy-folders'),
			'pro'		=> __('Pro', 'easy-folders'),
			'free'		=> __('Free', 'easy-folders'),
			'configure'		=> __('Configure', 'easy-folders'),
			'refresh_api_status'		=> __('Refresh API status', 'easy-folders'),
			'success_api_status_update'		=> __('API status update successfully', 'easy-folders'),
			'manage_website'		=> __('Manage Website', 'easy-folders'),
			'pro_feature_locked_tooltip'		=> __('In order to use this feature you have to upgrade to a Pro plan.', 'easy-folders'),
			'pro_feature_locked'		=> __('This feature is for Pro users only, to use this feature', 'easy-folders'),
			'upgrade_to_pro'		=> $upgrade_to_pro,
			'activate'		=> __('Activate', 'easy-folders'),
			'deactivate'		=> __('Deactivate', 'easy-folders'),
			'activate_module'		=> __('Activate %s', 'easy-folders'),
			'deactivate_module'		=> __('Deactivate %s', 'easy-folders'),
			'deactivate_module_sub'		=> __('If you no longer require %s module, you can disable this feature.', 'easy-folders'),
			'module_currently_disabled'		=> __('%s is currently disabled.', 'easy-folders'),
			'only_available_in_pro'		=> __('%s is only available in the Pro Plan.', 'easy-folders'),
			'module_only_available_in_pro_sub'		=> __('You need to upgrade to a Pro plan in order to use %s module. Upgrade to Pro now to get access to %s module along with tons of more	pro features and modules.', 'easy-folders'),
			'feature_only_available_in_pro_sub'		=> __('You need to upgrade to a Pro plan in order to use %s feature. Upgrade to Pro now to get access to %s feature along with tons of more	pro features and modules.', 'easy-folders'),
			'unlock_new_features'		=> __('Unlock new features.', 'easy-folders'),
			'unlock_new_features_sub'		=> $unlock_new_features_sub,
			'media_download'		=> __('Media Download', 'easy-folders'),
			'media_download_sub'		=> __('Download all the items from your media library or just the ones that you want. Selected items will be zipped and start downloading instantly.', 'easy-folders'),
			'folders_color'		=> __('Folders Color', 'easy-folders'),
			'folders_color_sub'		=> __('Make your folders stand out from the crowd by applying colors to them. Because different folders will be used for different purposes.', 'easy-folders'),
			'add_new_color'		=> __('Add new color', 'easy-folders'),
			'show_media_detail_on_hover'		=> __('Show Media Details on Hover', 'easy-folders'),
			'show_media_detail_on_hover_sub'		=> __('Show useful metadata such as title, size, type, date, dimension and more when you hover on an image.', 'easy-folders'),
			'alternative_text'		=> __('Alternative Text', 'easy-folders'),
			'file_url'		=> __('File URL', 'easy-folders'),
			'dimensions'		=> __('Dimensions', 'easy-folders'),
			'size'		=> __('Size', 'easy-folders'),
			'filename'		=> __('Filename', 'easy-folders'),
			'uploaded_by'		=> __('Uploaded By', 'easy-folders'),
			'starred_media_folder'		=> __('Starred Items & Folders', 'easy-folders'),
			'starred_media_folder_description'		=> __('Starring is a way to bookmark your important items or folders. This allows you to quickly access your most important items or folders at all times.', 'easy-folders'),
			'star_folders'		=> __('Star Folders', 'easy-folders'),
			'star_folders_sub'		=> __('Allow folders to be starred or not.', 'easy-folders'),
			'star_media'		=> __('Star Media & Posts', 'easy-folders'),
			'star_media_sub'		=> __('Allow Media & Posts to be starred or not.', 'easy-folders'),
			'trash_bin'		=> __('Trash', 'easy-folders'),
			'trash'		=> __('Trash', 'easy-folders'),
			'delete_permanently'		=> __('Delete Permanently', 'easy-folders'),
			'trash_bin_description'		=> __('The trash is temporary storage for items and folders set aside for deletion. In case something happens, they can be restored.', 'easy-folders'),
			'auto_delete_old_items'		=> __('Auto Delete Old Items', 'easy-folders'),
			'auto_delete_old_items_sub'		=> __('Media and Folders will be permanently deleted automatically from trash after a specified period of time.', 'easy-folders'),
			'auto_delete_old_items_explainer'		=> __('Easy Folders will automatically delete items older than <b>%s days</b> from trash.', 'easy-folders'),
			'days'		=> __('days', 'easy-folders'),
			'items_upon_folder_deletion'		=> __('Items Upon Folder Deletion', 'easy-folders'),
			'items_upon_folder_deletion_sub'		=> __('When a folder filled with items/media is deleted what should happen to those items inside?', 'easy-folders'),
			'move_to_trash_bin'		=> __('Move to Trash', 'easy-folders'),
			'move_to_uncategorized'		=> __('Move to Uncategorized', 'easy-folders'),
			'woocommerce_folders'		=> __('WooCommerce Folders', 'easy-folders'),
			'wooCommerce_folders_description'		=> __('Organize all of your WooCommerce product images into folders automatically created on basis of products, categories, and more.', 'easy-folders'),
			'sub_folders_creation'		=> __('Sub Folders Creation', 'easy-folders'),
			'sub_folders_creation_sub'		=> __('Sub folders will be created to categorize products in their respective categories.', 'easy-folders'),
			'sub_folders_creation_explainer'		=> __('Choose how you want to name your automatically sub folders.', 'easy-folders'),
			'based_on_category_name'		=> __('Based on Category Name', 'easy-folders'),
			'based_on_category_slug'		=> __('Based on Category Slug', 'easy-folders'),
			'based_on_category_id'		=> __('Based on Category ID #', 'easy-folders'),
			'gutenberg_gallery'		=> __('Gutenberg Gallery', 'easy-folders'),
			'gutenberg_gallery_sub'		=> __('Create dynamic galleries from a folder. Show images in columns, set the maximum number of images per column, choose the layout, and much more.', 'easy-folders'),
			'infinite_scrolling'		=> __('Infinite Scroll for Media Library', 'easy-folders'),
			'infinite_scrolling_sub'		=> __('If enabled, it will add the Infinite Scroll feature to your media library and removes the default Load More button.', 'easy-folders'),
			'third_party_compatibility'		=> __('3rd Party Integrations', 'easy-folders'),
			'custom_post_types_support'		=> __('Extend Easy Folders', 'easy-folders'),
			'custom_post_types_support_description'		=> __('Extend Easy Folders to manage large numbers of pages and custom post types as well.', 'easy-folders'),
			'custom_post_type_heading'		=> __('Use Easy Folders with: %s', 'easy-folders'),
			'custom_post_type_sub_heading'		=> __('Extend Easy Folders to organize %s into folders as well.'),
			'third_party_gutenberg'		=> __('Gutenberg', 'easy-folders'),
			'third_party_elementor'		=> __('Elementor', 'easy-folders'),
			'third_party_beaver_builder'		=> __('Beaver Builder', 'easy-folders'),
			'third_party_brizy_builder'		=> __('Brizy Builder', 'easy-folders'),
			'third_party_cornerstone_builder'		=> __('Cornerstone Builder', 'easy-folders'),
			'third_party_divi_builder'		=> __('Divi Builder', 'easy-folders'),
			'third_party_thrive_quiz_builder'		=> __('Thrive Quiz Builder', 'easy-folders'),
			'third_party_fusion_builder'		=> __('Fusion Builder', 'easy-folders'),
			'third_party_oxygen_builder'		=> __('Oxygen Builder', 'easy-folders'),
			'third_party_tatsu_builder'		=> __('Tatsu Builder', 'easy-folders'),
			'third_party_dokan'		=> __('Dokan', 'easy-folders'),
			'third_party_woocommerce'		=> __('WooCommerce', 'easy-folders'),
			'third_party_class_editor'		=> __('Classic Editor', 'easy-folders'),
			'third_party_compatibility_description'		=> __('Directly integrate Easy Folders into over 20+ plugins and themes. This means that you can now have Easy Folders media library management everywhere.', 'easy-folders'),
			'third_party_support'		=> __('%s Support', 'easy-folders'),
			'third_party_support_sub'		=> __('Integrate Easy Folders structure directly into %s.', 'easy-folders'),
			'general_settings'		=> __('General Settings', 'easy-folders'),
			'general_settings_description'		=> __('In this section, you will find all generic settings related to Easy Folders.', 'easy-folders'),
			'media_settings'		=> __('Media Settings', 'easy-folders'),
			'media_settings_description'		=> __('In this section, you will find all settings related to the media library.', 'easy-folders'),
			'folder_settings'		=> __('Folder Settings', 'easy-folders'),
			'folder_settings_description'		=> __('In this section, you will find all settings related to the folders.', 'easy-folders'),
			'import_export'		=> __('Import & Export', 'easy-folders'),
			'import_export_description'		=> __('In this section, you will find all settings related to importing and exporting data.', 'easy-folders'),
			'database_tools'		=> __('Database Tools', 'easy-folders'),
			'database_tools_description'		=> __('In this section, you will find all settings related to database and API.', 'easy-folders'),
			'system_status'		=> __('System Status', 'easy-folders'),
			'system_status_description'		=> __('Monitor your system\'s status and see the details of key components.', 'easy-folders'),
			'maximum_file_upload_size'		=> __('Max File Upload Size', 'easy-folders'),
			'maximum_file_upload_size_sub'		=> __('Configure maximum file upload size allowed by media library.', 'easy-folders'),
			'maximum_file_size'		=> __('Max file size', 'easy-folders'),
			'allowed_file_types'		=> __('Allowed File Types', 'easy-folders'),
			'allowed_file_types_sub'		=> __('If a specific file type is restricted by media library you can add that file type into allowed list here.', 'easy-folders'),
			'column_name'		=> __('Column Name', 'easy-folders'),
			'description'		=> __('Description', 'easy-folders'),
			'mime_type'		=> __('MIME Type', 'easy-folders'),
			'extension'		=> __('Extension', 'easy-folders'),
			'active'		=> __('Active', 'easy-folders'),
			'add_custom_file_types'		=> __('Add custom file types', 'easy-folders'),
			'file_description'		=> __('File Description', 'easy-folders'),
			'add'		=> __('Add', 'easy-folders'),
			'media_list_columns'		=> __('Media List Columns', 'easy-folders'),
			'media_list_columns_sub'		=> __('Manage and organize columns in the media list.', 'easy-folders'),
			'plugin_language'		=> __('Easy Folders Language', 'easy-folders'),
			'plugin_language_sub'		=> __('By default, Easy Folders will use the language you\'d set in <a href="%s" target={"_blank"}>Wordpress Admin Settings</a> if a matching translation is available.', 'easy-folders'),
			'restrict_settings_access'		=> __('Restrict Settings Access', 'easy-folders'),
			'restrict_settings_access_sub'		=> __('If enabled, only users with admin role will have access to Easy Folders setting pages.', 'easy-folders'),
			'auto_update_easyfolders'		=> __('Auto Update Easy Folders', 'easy-folders'),
			'auto_update_easyfolders_sub'		=> __('If enabled, plugin will be automatically updated to the latest version.', 'easy-folders'),
			'usage_tracking'		=> __('Usage Tracking', 'easy-folders'),
			'usage_tracking_sub'		=> __('Help us make your experience with Easy Folders better by allowing us to collect non-sensitive usage data.', 'easy-folders'),
			'plugin_settings_and_folders'		=> __('Easy Folders Settings & Folders', 'easy-folders'),
			'plugin_settings_and_folders_sub'		=> __('Import/Export your Easy Folders settings and folders, This option is useful for replicating Easy Folders settings across multiple websites.', 'easy-folders'),
			'import'		=> __('Import', 'easy-folders'),
			'export'		=> __('Export', 'easy-folders'),
			'settings_file'		=> __('Settings file', 'easy-folders'),
			'settings_file_explainer'		=> __('Import settings by locating settings file and clicking "%s".', 'easy-folders'),
			'plugin_settings'		=> __('Plugin settings', 'easy-folders'),
			'plugin_folders'		=> __('Folders', 'easy-folders'),
			'error_invalid_import_file'		=> __('Invalid file type! Only .XML file type is allowed', 'easy-folders'),
			'error_please_upload_file'		=> __('Please upload setting file', 'easy-folders'),
			'import_now'		=> __('Import now', 'easy-folders'),
			'export_now'		=> __('Export now', 'easy-folders'),
			'other_plugins'		=> __('Other Plugins', 'easy-folders'),
			'other_plugins_sub'		=> __('If you were using another plugin to manage media and posts for your website before switching to Easy Folders, you can import the settings and data from those plugins here.', 'easy-folders'),
			'clean_data'		=> __('Clean Data', 'easy-folders'),
			'import_data'		=> __('Import Data', 'easy-folders'),
			'other_plugin_details'		=> __('%1s <span>By %2s</span>', 'easy-folders'),
			'other_plugin_details_sub'		=> __('We found you have <strong>(%1s)</strong> folders you created with <strong>%2s</strong> plugin.', 'easy-folders'),
			'no_plugin_detected'		=> __('No plugin detected with importable data.', 'easy-folders'),
			'update_api_status'		=> __('Update API Status', 'easy-folders'),
			'update_api_status_sub'		=> __('If you are having issue with enabling pro features you can force the API to update your subscription status here.', 'easy-folders'),
			'forcefully_update_api_status'		=> __('Forcefully update API status', 'easy-folders'),
			'recreate_missing_tables'		=> __('Re-create missing database tables', 'easy-folders'),
			'recreate_missing_tables_sub'		=> __('Check if required tables exist and create them if not.', 'easy-folders'),
			'recreate_missing_tables'		=> __('Re-create Missing Database Tables', 'easy-folders'),
			'recreate_missing_tables_sub'		=> __('Check if required tables exist and create them if not.', 'easy-folders'),
			'recreate_tables'		=> __('Re-create tables', 'easy-folders'),
			'delete_plugin_data'		=> __('Delete Easy Folders Data Upon Plugin Removal', 'easy-folders'),
			'delete_plugin_data_sub'		=> __('Remove all Easy Folders data on uninstall.', 'easy-folders'),
			'delete_plugin_data_explainer'		=> __('When you uninstall the plugin, what do you want to do with your settings, folders and all other data relating to Easy Folders? You can save them for next time, or wipe them back to factory settings.', 'easy-folders'),
			'are_you_sure_you_want_to_reset_factory_settings'		=> __('Are you sure you want to reset default settings?', 'easy-folders'),
			'manual_data_removal'		=> __('Manual Easy Folders Data Removal', 'easy-folders'),
			'manual_data_removal_sub'		=> __('Wipe all data and reset to default factory settings.', 'easy-folders'),
			'manual_data_removal_explainer'		=> __('Proceed with caution, factory reset will wipe out all settings, media folders and license key, this action is irreversible.', 'easy-folders'),
			'reset_factory_settings'		=> __('Reset factory settings', 'easy-folders'),
			'copy_site_info'		=> __('Copy site info to clipboard', 'easy-folders'),
			'success_copied_to_clipboard'		=> __('Successfully copied to clipboard', 'easy-folders'),
			'activate_license'		=> __('Activate license', 'easy-folders'),
			'deactivate_license'		=> __('Deactivate license', 'easy-folders'),
			'easyfolders_license_activation'		=> __('Easy Folders License Activation', 'easy-folders'),
			'easyfolders_license_activation_sub'		=> __('Activate license key for automatic updates and awesome support', 'easy-folders'),
			'license_key_placeholder'		=> __('Enter license key...', 'easy-folders'),
			'do_not_have_license_buy_now'		=> __('Don\'t have license key? <a href="%s" target={"_blank"}>Buy now</a>', 'easy-folders'),
			'secure'		=> __('secure', 'easy-folders'),
			'sidebar_upgrade_to_pro_sub'		=> __('Unlock true potential of Easy Folders.', 'easy-folders'),
			'sidebar_join_fb_group'		=> __('Join Private FB Group', 'easy-folders'),
			'sidebar_join_fb_group_sub'		=> __('Discussions, questions, tutorials, sneak peaks, and exclusive giveaways.', 'easy-folders'),
			'sidebar_youtube_channel'		=> __('Easy Folders YouTube Channel', 'easy-folders'),
			'sidebar_youtube_channel_sub'		=> __('Take a visual dive into everything Easy Folders has to offer.', 'easy-folders'),
			'sidebar_helpful_docs'		=> __('Helpful Docs', 'easy-folders'),
			'sidebar_helpful_docs_sub'		=> __('Browse through helpful tutorials/articles to better understand Easy Folders.', 'easy-folders'),
			'sidebar_ticket_support'		=> __('Ticket Support', 'easy-folders'),
			'sidebar_ticket_support_sub'		=> __('Get direct help quickly from our qualified support team.', 'easy-folders'),
			'sidebar_suggest_a_feature'		=> __('Suggest a Feature', 'easy-folders'),
			'sidebar_suggest_a_feature_sub'		=> __('Got an idea or suggestion for Easy Folders? we would love to hear it.', 'easy-folders'),
			'sidebar_affiliate_program'		=> __('Affiliate Program', 'easy-folders'),
			'sidebar_affiliate_program_sub'		=> __('Start promoting Easy Folders and earn flat %s from each sale.', 'easy-folders'),
			'let_us_help_you'		=> __('Let us help you', 'easy-folders'),
			'let_us_help_you_sub'		=> __('Hey %s, Would you like to unlock the full potential of your Easy Folders? We created a really short course consisting of 5 emails only (1 email/day) packed with resources for website speed optimization, media management and much more - just for you!', 'easy-folders'),
			'enter_your_email'		=> __('Enter your email...', 'easy-folders'),
			'send_me'		=> __('Send me', 'easy-folders'),
			'no_spam'		=> __('Easy Folders respect your privacy. No Spam!', 'easy-folders'),
			'success_email_verified'		=> __('Email verified successfully', 'easy-folders'),
			'installer_getting_started'		=> __('Getting started', 'easy-folders'),
			'installer_import_data'		=> __('Import data', 'easy-folders'),
			'installer_free_course'		=> __('Free Course', 'easy-folders'),
			'installer_usage_tracking'		=> __('Usage tracking', 'easy-folders'),
			'installer_ready'		=> __('Ready', 'easy-folders'),
			'welcome_to_installer'		=> __('Welcome to Easy Folders setup wizard!', 'easy-folders'),
			'welcome_to_installer_sub'		=> __('Thanks for installing Easy Folders. You are going to be rocking out with your new media library in no time. To get started, we\'ll walk you through a few simple steps. It\'s easy as 1-2-3 ', 'easy-folders'),
			'lets_get_started'		=> __('Let\'s get started', 'easy-folders'),
			'import_from_other_plugins'		=> __('Import Data from other Media Library Plugins.', 'easy-folders'),
			'back'		=> __('Back', 'easy-folders'),
			'skip_step'		=> __('Skip this step', 'easy-folders'),
			'continue'		=> __('Continue', 'easy-folders'),
			'allow_and_continue'		=> __('Allow & Continue', 'easy-folders'),
			'sign_up_for_email_course'		=> __('Sign up for our 5 part short email course.', 'easy-folders'),
			'signed_up_for_email_course'		=> __('Great! You are now signed-up for the course.', 'easy-folders'),
			'signed_up_for_email_course_sub'		=> __('All you have to do now is keep an eye on your inbox for a daily email from RipeBits.', 'easy-folders'),
			'help_us_usage_tracking'		=> __('Help us to make your Easy Folders experience better.', 'easy-folders'),
			'help_us_usage_tracking_sub'		=> __('%s, in order to make your Easy Folders experience better and secure we need to collect some non-sensitive usage data.', 'easy-folders'),
			'what_permissions_are_being_granted'		=> __('What permissions are being granted?', 'easy-folders'),
			'your_profile_overview'		=> __('Your profile overview', 'easy-folders'),
			'your_profile_overview_sub'		=> __('Name, email and geo.', 'easy-folders'),
			'your_site_overview'		=> __('Your site overview', 'easy-folders'),
			'your_site_overview_sub'		=> __('Site address, WordPress version and tech stack.', 'easy-folders'),
			'current_plugins_events'		=> __('Current plugins events', 'easy-folders'),
			'current_plugins_events_sub'		=> __('Activation, deactivation and uninstall.', 'easy-folders'),
			'congratulations_your_easyfolders_is_ready_now'		=> __('Congratulations, your Easy Folders is ready now!', 'easy-folders'),
			'congratulations_your_easyfolders_is_ready_now_sub'		=> __('Make sure to <a href="%1s" target={"_blank"}>subscribe Easy Folders on YouTube</a> and <a href="%2s" target={"_blank"}>Join Private FB Group</a> for discussions, questions, tutorials, sneak peaks, and exclusive giveaways.', 'easy-folders'),
			'goto_settings'		=> __('Goto settings', 'easy-folders'),
			'goto_library'		=> __('Goto media library', 'easy-folders'),
			'click_here_to_skip_installation'		=> __('Click here to skip installation (Not Recommended)', 'easy-folders'),
			'are_you_sure_to_want_to_skip_installation'		=> __('Are you sure to want to skip installation?', 'easy-folders'),
			'are_you_sure_to_want_to_skip_installation_sub'		=> __('We highly recommend you not skip installation. The installer will guide you through each important step to get familiar with Easy Folders and all the settings. It will hardly take a few minutes.', 'easy-folders'),
			'new'		=> __('New', 'easy-folders'),
			'file_upload'		=> __('File Upload', 'easy-folders'),
			'folder_upload'		=> __('Folder Upload', 'easy-folders'),
			'folders'		=> __('Folders', 'easy-folders'),
			'files'		=> __('Files', 'easy-folders'),
			'all_files'		=> __('All Files', 'easy-folders'),
			'root'		=> __('Root', 'easy-folders'),
			'uncategorized'		=> __('Uncategorized', 'easy-folders'),
			'starred'		=> __('Starred', 'easy-folders'),
			'trashed'		=> __('Trashed', 'easy-folders'),
			'all_folders'		=> __('All Folders', 'easy-folders'),
			'select_folder'		=> __('Select Folder', 'easy-folders'),
			'folders_search'		=> __('Folders search', 'easy-folders'),
			'search_folders_placeholder'		=> __('Search folders...', 'easy-folders'),
			'folder_name_placeholder'		=> __('Folder name...', 'easy-folders'),
			'filter'		=> __('Filter', 'easy-folders'),
			'no'		=> __('No', 'easy-folders'),
			'folder_selected'		=> __('folder selected', 'easy-folders'),
			'folders_selected'		=> __('folders selected', 'easy-folders'),
			'item_selected'		=> __('item selected', 'easy-folders'),
			'items_selected'		=> __('items selected', 'easy-folders'),
			'upgrade'		=> __('Upgrade', 'easy-folders'),
			'go_pro'		=> __('Go Pro', 'easy-folders'),
			'name'		=> __('Name', 'easy-folders'),
			'title'		=> __('Title', 'easy-folders'),
			'date'		=> __('Date', 'easy-folders'),
			'type'		=> __('Type', 'easy-folders'),
			'status'		=> __('Status', 'easy-folders'),
			'attach'		=> __('Attach', 'easy-folders'),
			'add_to'		=> __('Add to', 'easy-folders'),
			'move_to'		=> __('Move to', 'easy-folders'),
			'download'		=> __('Download', 'easy-folders'),
			'delete'		=> __('Delete', 'easy-folders'),
			'restore'		=> __('Restore', 'easy-folders'),
			'delete_forever'		=> __('Delete forever', 'easy-folders'),
			'cancel'		=> __('Cancel', 'easy-folders'),
			'new_folder'		=> __('New Folder', 'easy-folders'),
			'remove_from_starred'		=> __('Remove from starred', 'easy-folders'),
			'add_to_starred'		=> __('Add to Starred', 'easy-folders'),
			'goto_item_location'		=> __('Goto item location', 'easy-folders'),
			'cut'		=> __('Cut', 'easy-folders'),
			'paste'		=> __('Paste', 'easy-folders'),
			'rename'		=> __('Rename', 'easy-folders'),
			'shortcut'		=> __('Shortcut', 'easy-folders'),
			'create_a_shortcut'		=> __('Create a shortcut', 'easy-folders'),
			'delete_shortcut'		=> __('Delete Shortcut', 'easy-folders'),
			'close'		=> __('Close', 'easy-folders'),
			'shortcut_cannot_opened'		=> __('Shortcut can’t be opened', 'easy-folders'),
			'shortcut_cannot_opened_desc'		=> __('The shortcut %1s can’t be opened because the original item can’t be found.', 'easy-folders'),
			'folder_color'		=> __('Folder color', 'easy-folders'),
			'remove_folder_color'		=> __('Remove folder color', 'easy-folders'),
			'folders_sorting'		=> __('Folders sorting', 'easy-folders'),
			'media_sorting'		=> __('Media sorting', 'easy-folders'),
			'order_by'		=> __('Order By', 'easy-folders'),
			'ascending'		=> __('Ascending', 'easy-folders'),
			'descending'		=> __('Descending', 'easy-folders'),
			'sort_by'		=> __('Sort By', 'easy-folders'),
			'sort_by_ascending'		=> __('Sort by Ascending', 'easy-folders'),
			'sort_by_descending'		=> __('Sort by Descending', 'easy-folders'),
			'sort_by_name'		=> __('Name', 'easy-folders'),
			'sort_by_date'		=> __('Date', 'easy-folders'),
			'sort_by_date_modified'		=> __('Date Modified', 'easy-folders'),
			'sort_by_author'		=> __('Author', 'easy-folders'),
			'reset'		=> __('Reset', 'easy-folders'),
			'bulk_select'		=> __('Bulk select', 'easy-folders'),
			'bulk_select_folders'		=> __('Bulk Select Folders', 'easy-folders'),
			'select_destination_for'		=> __('Select destination for', 'easy-folders'),
			'number_selected_item'		=> __('%s selected item', 'easy-folders'),
			'number_selected_items'		=> __('%s selected items', 'easy-folders'),
			'move_here'		=> __('Move here', 'easy-folders'),
			'empty_trash'		=> __('Empty Trash', 'easy-folders'),
			'uploading_item'		=> __('Uploading %s item', 'easy-folders'),
			'uploading_items'		=> __('Uploading %s items', 'easy-folders'),
			'item_was_uploaded'		=> __('%s item was uploaded', 'easy-folders'),
			'items_were_uploaded'		=> __('%s items were uploaded', 'easy-folders'),
			'and_item_failed'		=> __('and %s item failed', 'easy-folders'),
			'and_items_failed'		=> __('and %s items failed', 'easy-folders'),
			'item_was_uploaded_successfully'		=> __('%s item was uploaded successfully', 'easy-folders'),
			'items_were_uploaded_successfully'		=> __('%s items were uploaded successfully', 'easy-folders'),
			'processing'		=> __('Processing...', 'easy-folders'),
			'uploaded_successfully'		=> __('Uploaded successfully', 'easy-folders'),
			'upload_failed_try_again'		=> __('Upload failed. Try again', 'easy-folders'),
			'item_failed_to_upload'		=> __('%s item failed to upload', 'easy-folders'),
			'items_failed_to_upload'		=> __('%s items failed to upload', 'easy-folders'),
			'upload_pending'		=> __('Upload pending', 'easy-folders'),
			'starting_upload'		=> __('Starting upload...', 'easy-folders'),
			'upload_complete'		=> __('Upload complete', 'easy-folders'),
			'percent_out_of'		=> __('%1s (%2s out of %3s)', 'easy-folders'),
			'total_size'		=> __('Total size: %s', 'easy-folders'),
			'processing_in_progress'		=> __('Processing…', 'easy-folders'),
			'error_enter_folder_name'		=> __('Please enter a valid folder name', 'easy-folders'),
			'drop_files_to_upload_them'		=> __('Drop files to upload them instantly to:', 'easy-folders'),
			'are_you_sure'		=> __('Are you sure?', 'easy-folders'),
			'are_you_sure_you_want_to_delete_item'		=> __('Are you sure you want to trash %s selected item?', 'easy-folders'),
			'are_you_sure_you_want_to_delete_items'		=> __('Are you sure you want to trash %s selected items?', 'easy-folders'),
			'are_you_sure_you_want_to_delete_permanently_item'		=> __('Are you sure you want to permanently delete %s selected item?', 'easy-folders'),
			'are_you_sure_you_want_to_delete_permanently_items'		=> __('Are you sure you want to permanently delete %s selected items?', 'easy-folders'),
			'are_you_sure_you_want_to_delete_permanently_in_bin'		=> __('Are you sure you want to permanently delete all the items in the Bin?', 'easy-folders'),
			'you_have_not_selected_folder_file_yet'		=> __('You have not selected any folder/file yet.', 'easy-folders'),
			'add_item_to_a_new_folder'		=> __('Add %s selected item to a new folder', 'easy-folders'),
			'add_items_to_a_new_folder'		=> __('Add %s selected items to a new folder', 'easy-folders'),
			'add_items_to_a_new_folder_description'		=> __('A new folder will be created, and all the selected items will be moved into that folder.', 'easy-folders'),
			'create_and_move'		=> __('Create and move', 'easy-folders'),
			'are_you_sure_you_want_to_restore_item'		=> __('Are you sure you want to restore %s selected item?', 'easy-folders'),
			'are_you_sure_you_want_to_restore_items'		=> __('Are you sure you want to restore %s selected items?', 'easy-folders'),
			'no_search_result_found'		=> __('No search result found!', 'easy-folders'),
			'no_search_result_found_sub'		=> __('Use more generic words or double check your spelling.', 'easy-folders'),
			'no_search_result_found_for'		=> __('No search result found for "%s"', 'easy-folders'),
			'there_are_no_items_here'		=> __('There are no items here!', 'easy-folders'),
			'there_are_no_items_here_sub'		=> __('Start uploading files or folders.', 'easy-folders'),
			'there_are_no_items_here_uncategorized_sub'		=> __('Those files which doesn\'t fall under any category are shown here.', 'easy-folders'),
			'there_are_no_items_here_starred_sub'		=> __('Starred items will be shown here.', 'easy-folders'),
			'trash_bin_is_empty'		=> __('Trash is empty!', 'easy-folders'),
			'trash_bin_is_empty_sub'		=> __('Once you delete an item it will be moved here.', 'easy-folders'),
			'why_you_are_deactivating_your_easyfolders'		=> __('Please leave us feedback on why you are deactivating your Easy Folders', 'easy-folders'),
			'does_not_have_features'		=> __('It doesn\'t have features that I want.', 'easy-folders'),
			'plugin_does_not_work'		=> __('Plugin doesn\'t work.', 'easy-folders'),
			'incompatible_with_other_themes_plugins'		=> __('Incompatible with other themes/plugins.', 'easy-folders'),
			'found_another_plugin_that_works_better'		=> __('Found another plugin that works better.', 'easy-folders'),
			'do_not_know_how_to_use_it'		=> __('Don\'t know how to use it.', 'easy-folders'),
			'temporary_deactivation_i_will_use_again'		=> __('Temporary deactivation, I will use again.', 'easy-folders'),
			'other_reason'		=> __('Other reason.', 'easy-folders'),
			'please_select_option'		=> __('Please select a reason for deactivating plugin.', 'easy-folders'),
			'feedback_suggest_a_feature'		=> __('Suggest a Feature', 'easy-folders'),
			'feedback_suggest_a_feature_sub'		=> __('Do you have an idea or suggestion for Easy Folders? If you have thoughts on features, integrations, addons, or improvements - we want to hear it! We appreciate all feedback and insight from our users. - <a href="%s" target={"_blank"}>Click here to suggest a feature</a>.', 'easy-folders'),
			'get_help_from_easyfolders_support_team'		=> __('Get help from RipeBits support team', 'easy-folders'),
			'get_help_from_easyfolders_support_team_sub'		=> __('Let our top-notch support team look into the issue and solve it for you asap - <a href="%s" target={"_blank"}>Click here to get help from support team</a>.', 'easy-folders'),
			'with_which_themes_plugins_easyfolders_is_incompatible'		=> __('With which themes/plugins Easy Folders is incompatible?', 'easy-folders'),
			'with_which_themes_plugins_easyfolders_is_incompatible_placeholder'		=> __('Enter the name of themes/plugins and incompatibility issue here...', 'easy-folders'),
			'your_name_placeholder'		=> __('Your name...', 'easy-folders'),
			'your_email_placeholder'		=> __('Your email...', 'easy-folders'),
			'your_feedback_placeholder'		=> __('Your feedback...', 'easy-folders'),
			'feedback_explainer'		=> __('We appreciate you taking your time to give feedback. Your feedback is really valuable and helps us to improve Easy Folders. Upon feedback submission your contact details (email & name) will be shared as well so if we need more info we can get in touch with you. We will never spam you or sell your email address.', 'easy-folders'),
			'what_is_the_name_of_the_other_plugin'		=> __('What\'s the name of the other plugin?', 'easy-folders'),
			'what_is_the_name_of_the_other_plugin_placeholder'		=> __('Enter the name of the other plugin and in which areas it better than Easy Folders here...', 'easy-folders'),
			'we_got_you_all_covered'		=> __('We got you all covered', 'easy-folders'),
			'we_got_you_all_covered_sub'		=> __('Getting used to a new plugin can be tricky sometimes, but don\'t worry to help you better understand Easy Folders we got <a href="%1s" target={"_blank"}>helpful docs here</a>, We also have a dedicated <a href="%2s" target={"_blank"}>youtube channel here</a> and a <a href="%3s" target={"_blank"}>private facebook group here</a>.', 'easy-folders'),
			'can_you_please_explain_why_are_you_deactivating_easyfolders'		=> __('Can you please explain why are you deactivating Easy Folders?', 'easy-folders'),
			'enter_detail_here_placeholder'		=> __('Enter detail here...', 'easy-folders'),
			'skip_and_deactivate'		=> __('Skip & Deactivate', 'easy-folders'),
			'hey_got_a_minute'		=> __('Hey %s, got a minute?', 'easy-folders'),
			'how_satisfied_are_you'		=> __('How satisfied are you with the Easy Folders so far?', 'easy-folders'),
			'bad'		=> __('Bad', 'easy-folders'),
			'poor'		=> __('Poor', 'easy-folders'),
			'average'		=> __('Average', 'easy-folders'),
			'great'		=> __('Great', 'easy-folders'),
			'excellent'		=> __('Excellent', 'easy-folders'),
			'what_do_you_think'		=> __('What do you think we could do to improve Easy Folders?', 'easy-folders'),
			'submit_feedback'		=> __('Submit feedback', 'easy-folders'),
			'submit_feedback_after'		=> __('%1s, Thank you for your feedback. If you could rate <b>Easy Folders <a href="%2s" target={"_blank"}>&#9733;&#9733;&#9733;&#9733;&#9733;</a></b> on <a href="%2s" target={"_blank"}>WordPress.org</a>, it would be awesome. Your rating will help new users to feel more confident in choosing Easy Folders.', 'easy-folders'),
			'leave_a_review_now'		=> __('Leave a review now', 'easy-folders'),
			'we_appreciate_your_help'		=> __('It will hardly take a few minutes. We appreciate your help!', 'easy-folders'),
			'hellobar_upgrade_to_pro'		=> $hellobar_upgrade_to_pro,
			'hellobar_download_pro_version'		=> __('To use Pro modules and features you need to download and install Pro version of Easy Folders. <a href="%s" target={"_blank"}>Click here to Download Pro version</a>&#160;<b>&#8594;</b>', 'easy-folders'),
			'hellobar_woocommerce_not_synchronized'		=> __('Your WooCommerce product images are not synchronized yet', 'easy-folders'),
			'hellobar_woocommerce_start_synchronizing_now'		=> __('Start synchronizing now', 'easy-folders'),
			'auto_organize_woocommerce_product_images'		=> __('Auto Organize WooCommerce Product Images', 'easy-folders'),
			'auto_organize_woocommerce_product_images_sub'		=> __('Click on "<b>Start auto organizing</b>" button below to automatically organize existing WooCommerce product images into folders and sub-folders based on categories and sub-categories.', 'easy-folders'),
			'start_auto_organizing'		=> __('Start auto organizing', 'easy-folders'),
			'organizing_in_progress'		=> __('Organizing in progress', 'easy-folders'),
			'organizing_in_progress_sub'		=> __('WooCommerce Products Auto Organizing is in progress, you need to keep this tab open until the process completes.', 'easy-folders'),
			'success_synchronized_woocommerce'		=> __('Easy Folders synchronized successfully with your WooCommerce products.', 'easy-folders'),
			'thank_you_for_using_easyfolders'		=> __('Please rate <b>Easy Folders <a href="%1s" target={"_blank"}>&#9733;&#9733;&#9733;&#9733;&#9733;</a></b> on <a href="%2s" target={"_blank"}>WordPress.org</a> to help us spread the word. Thank you from the RipeBits team &#9829;', 'easy-folders'),
			'something_went_wrong'		=> __('Something went wrong', 'easy-folders'),
			'try_again'		=> __('Try again', 'easy-folders'),
			'upgrade_to_easyfolders_pro'		=> __('Upgrade to Easy Folders Pro', 'easy-folders'),
			'hero_section_description_one'		=> $hero_section_description_one,
			'hero_section_description_two'		=> __('Use the Woocommerce folders feature to automatically organize your media into folders and make folders stand out using colors or starred media & folders feature. Get Pro to unlock the true power of Easy Folders.', 'easy-folders'),
			'pro_features'		=> __('Pro Features', 'easy-folders'),
			'pro_features_sub'		=> __('Upgrading to Easy Folders Pro will get you the following benefits.', 'easy-folders'),
			'un_restricted_media_library_feature'		=> __('Un-restricted media library', 'easy-folders'),
			'un_restricted_media_library_feature_sub'		=> __('Get Pro to remove all restrictions from the media library on all features such as folder and media sorting, folder uploading, folder search, cut, paste, move to, add to, create shortcuts, and many more...', 'easy-folders'),
			'media_download_feature_sub'		=> __('With Pro you can download all the items from your media library or just the ones that you want. Selected items will be zipped and start downloading instantly.', 'easy-folders'),
			'folders_color_feature_sub'		=> __('Use Pro to make your folders stand out from the crowd by applying colors to them. Because different folders will be used for different purposes.', 'easy-folders'),
			'starred_media_folder_feature_sub'		=> __('Starring is a way to bookmark your important items or folders. Pro allows you to use this feature to quickly access your most important media or folders at all times.', 'easy-folders'),
			'woocommerce_folders_feature_sub'		=> __('Use Pro to organize all of your WooCommerce product images into folders automatically created on basis of products, categories, and more...', 'easy-folders'),
			'third_party_compatibility_feature_sub'		=> __('Get Pro to directly integrate Easy Folders into over 20+ plugins and themes. This means that you can now have Easy Folders media library management everywhere.', 'easy-folders'),
			'custom_post_types_support_feature_sub'		=> __('Get Pro to directly integrate Easy Folders into Post Types. This means that you can now have Easy Folders media library management in any custom post type.', 'easy-folders'),
			'gutenberg_gallery_feature_sub'		=> __('With Pro you can create dynamic galleries from a folder. Show images in columns, set the maximum number of images per column, choose the layout, and much more.', 'easy-folders'),
			'and_more_features'		=> __('And many many more...', 'easy-folders'),
			'and_more_features_sub'		=> __('Click here to see a complete list of all the Pro features that Easy Folders has to offer.', 'easy-folders'),
			'empowering_thousands_of_websites'		=> __('Empowering thousands of websites from all over the world', 'easy-folders'),
			'number_millions'		=> __('%s Million', 'easy-folders'),
			'active_users'		=> __('Active Users', 'easy-folders'),
			'customer_review_1'		=> __('The plugin is extremely useful for managing the WordPress Media library. I highly recommend using Easy Folders for all of your media management.', 'easy-folders'),
			'customer_review_2'		=> __('Almost anyone can make a plugin, but few can make a great one like this, and almost no one achieves the level of excellence reached by RipeBits Team! They not only provide quality plugins, at affordable prices, with good update policies, but they back it all up with real people offering friendly and helpful support.', 'easy-folders'),
			'customer_review_3'		=> __('Easy Folders Pro is a must-have WordPress plugin that every web developer, designer and publisher should have in their arsenal. The fact that you can use it as a lite plugin or choose PRO features make Easy Folders Pro incredibly versatile.', 'easy-folders'),
			'get_started_with_easyfolders_pro_today'		=> __('Get started with Easy Folders Pro today', 'easy-folders'),
			'get_started_with_easyfolders_pro_today_sub'		=> __('%s of customers are happy with Easy Folders Pro, and thinks it\'s worth every penny as a Easy Folders user you\'ll get a free trial, so you can see what all the fuss is about.', 'easy-folders'),
			'joyride_modal_title'		=> __('Thank you for installing Easy Folders', 'easy-folders'),
			'joyride_modal_sub'		=> __('We have a small tour for you to help better understand Easy Folders and to unleash its true power. It will hardly take a minute to complete.We highly recommend you to take this tour.', 'easy-folders'),
			'joyride_modal_action'		=> __('Lets start', 'easy-folders'),
			'joyride_next'		=> __('Next', 'easy-folders'),
			'joyride_last'		=> __('Last', 'easy-folders'),
			'joyride_step_add_new_title'		=> __('Upload new files or folders', 'easy-folders'),
			'joyride_step_add_new_content'		=> __('Use this button to upload files from your computer or to create a new folder.<br />You can also drag and drop files and folders into the media library.', 'easy-folders'),
			'joyride_step_all_files_title'		=> __('All Files', 'easy-folders'),
			'joyride_step_all_files_content'		=> __('All Files will be shown inside this root folder irrespective of their actual location in media library.', 'easy-folders'),
			'joyride_step_uncategorized_title'		=> __('Uncategorized', 'easy-folders'),
			'joyride_step_uncategorized_content'		=> __('Media items which are not attached to any folder will be shown here.', 'easy-folders'),
			'joyride_step_folders_tree_title'		=> __('Folders Tree', 'easy-folders'),
			'joyride_step_folders_tree_content'		=> __('Any folder you create will be shown here.<br />You can also drag and drop files directly into these folders.', 'easy-folders'),
			'joyride_step_grid_list_title'		=> __('Grid and List View', 'easy-folders'),
			'joyride_step_grid_list_content'		=> __('Use these buttons to switch between grid and list view.', 'easy-folders'),
			'joyride_step_search_media_filter_title'		=> __('Media searching and filtering', 'easy-folders'),
			'joyride_step_search_media_filter_content'		=> __('You can search for files and folders using this search box. Also, you can apply filters or bulk select items using the filter button.', 'easy-folders'),
			'joyride_step_media_items_title'		=> __('Files and Folders', 'easy-folders'),
			'joyride_step_media_items_content'		=> __('<div>All media items will be shown here for selected folder along with sub-folders if there are any.<br />To bulk-select items try dragging mouse while holding the click from one corner.</div>', 'easy-folders'),
			'joyride_step_last'		=> __('<h2>Thats all for now, Have fun!</h2>Some final tips for you:<ul> <li>Drag your mouse from the one corner while holding the click to bulk select items.</li><li>Right click on any file or folder to see more options.</li> <li>Use bulk-bar to perform bulk actions on selected items.</li><li>Use the <strong>Modules</strong> section to manage all feature.</li><li>Use the <strong>Settings</strong> section to configure the plugin.</li></ul>', 'easy-folders'),
			'folders_color_updated' => __('%1$s folders color updated.', 'easy-folders'),
			'folder_color_updated' => __('"%1$s" color updated.', 'easy-folders'),
			'items_were_added_to_starred' => __('%1$s items were added to starred.', 'easy-folders'),
			'items_were_removed_from_starred' => __('%1$s items were removed from starred.', 'easy-folders'),
			'item_was_added_to_starred' => __('"%1$s" was added to starred.', 'easy-folders'),
			'item_was_removed_from_starred' => __('"%1$s" was removed from starred.', 'easy-folders'),
			'single_item_was_added_to_starred' => __('1 item was added to starred.', 'easy-folders'),
			'single_item_was_removed_from_starred' => __('1 item was removed from starred.', 'easy-folders'),
			'some_general_error_msg' => __('Some error occurred, please try again', 'easy-folders'),
			'select'		=> __('Select', 'easy-folders'),
		);

		return $translation;
    }

}