<?php

/**
 * Fired during plugin uninstallation
 * @link       https://ripebits.com
 * @since      1.0.0
 * @package    EasyFolders
 * @subpackage EasyFolders/includes
 */

/**
 * Fired during plugin uninstallation.
 * This class defines all code necessary to run during the plugin's uninstallation.
 * @since      1.0.0
 * @package    EasyFolders
 * @subpackage EasyFolders/includes
 */
class Easy_Folders_Uninstall {

    /**
     * Folder table
     * @since 1.0.0
     * @var string $folder_table
    */
	private static $folder_table = 'efs';

    /**
     * Attachment Folder relation table
     * @since 1.0.0
     * @var string $relation_table
    */
	private static $relation_table = 'efs_attachment_folder';

    /**
     * Upload file types
     * @since 1.0.0
     * @var string $upload_file_types
    */
    private static $upload_file_types = 'efs_upload_file_types';

    /**
     * Colors table
     * @since 1.0.0
     * @var string $efs_colors
    */
    private static $efs_colors = 'efs_colors';

	/**
	 * Fired during plugin uninstallation.
	 * @since 1.0.0
     * @return void
	 */
	public static function uninstall() {

		global $wpdb;
		
		$settings = (array) Easy_Folders_Settings::loadSettings();
		
        //Account uninstall time
		Easy_Folders_Helper::addOrUpdateOption(EASY_FOLDERS_PREFIX . 'account-uninstall-timestamp', time());

		//Save usage tracking
		Easy_Folders_Settings::saveUsageTracking(['current_status' => 'Uninstalled']);

		if(isset($settings['is_plugin_removal_delete_data']) && $settings['is_plugin_removal_delete_data'] == 1) {

			$wpdb->query( "DROP TABLE IF EXISTS ".self::getTable(self::$folder_table) );
			$wpdb->query( "DROP TABLE IF EXISTS ".self::getTable(self::$relation_table) );
			$wpdb->query( "DROP TABLE IF EXISTS ".self::getTable(self::$upload_file_types) );
			$wpdb->query( "DROP TABLE IF EXISTS ".self::getTable(self::$efs_colors) );

            // Option names prefixed with EASY_FOLDERS_PREFIX.
            $wfiles_keys = array(
                'easyfolders_version',
                EASY_FOLDERS_PREFIX . 'settings_updated',
                EASY_FOLDERS_PREFIX . 'hide_easyfolders_welcome',
                EASY_FOLDERS_PREFIX . 'hide_update_info',
                EASY_FOLDERS_PREFIX . 'install-type',
                EASY_FOLDERS_PREFIX . 'version',
                EASY_FOLDERS_PREFIX . 'scan',
                EASY_FOLDERS_PREFIX . 'settings',
                EASY_FOLDERS_PREFIX . 'networkwide',
                EASY_FOLDERS_PREFIX . 'conflict-notice',
                EASY_FOLDERS_PREFIX . 'account-connect-notice',
                EASY_FOLDERS_PREFIX . 'initial-trial-upgrade-notice',
                EASY_FOLDERS_PREFIX . 'account-payment-due-notice',
                EASY_FOLDERS_PREFIX . 'upgrade-to-pro-notice',
                EASY_FOLDERS_PREFIX . 'rating',
                EASY_FOLDERS_PREFIX . 'rating-hide',
                EASY_FOLDERS_PREFIX . 'rating-hide-count',
                EASY_FOLDERS_PREFIX . 'rating-id',
                EASY_FOLDERS_PREFIX . 'feedback-id',
                EASY_FOLDERS_PREFIX . 'install-hide',
                EASY_FOLDERS_PREFIX . 'install-hide-count',
                EASY_FOLDERS_PREFIX . 'usage-tracking-hide',
                EASY_FOLDERS_PREFIX . 'usage-tracking-hide-count',
                EASY_FOLDERS_PREFIX . 'usage-tracking-notice-hide',
                EASY_FOLDERS_PREFIX . 'rate-notice-hide',
                EASY_FOLDERS_PREFIX . 'rate-notice-already-done',
                EASY_FOLDERS_PREFIX . 'upgrade-hellobar-hide',
                EASY_FOLDERS_PREFIX . 'upgrade-hellobar-hide-count',
                EASY_FOLDERS_PREFIX . 'newsletter-hide',
                EASY_FOLDERS_PREFIX . 'newsletter-id',
                EASY_FOLDERS_PREFIX . 'activation-redirect',
                EASY_FOLDERS_PREFIX . 'woocommerce-sync-hide',
                EASY_FOLDERS_PREFIX . 'usage-tracking-disable-timestamp',
                EASY_FOLDERS_PREFIX . 'account-connection-timestamp',
                EASY_FOLDERS_PREFIX . 'subscription-upgrade-timestamp',
                EASY_FOLDERS_PREFIX . 'subscription-downgrade-timestamp',
                EASY_FOLDERS_PREFIX . 'account-activation-timestamp',
                EASY_FOLDERS_PREFIX . 'account-deactivation-timestamp',
                EASY_FOLDERS_PREFIX . 'account-uninstall-timestamp',
                EASY_FOLDERS_PREFIX . 'account-plan-id',
                EASY_FOLDERS_PREFIX . 'activation-country-code',
                EASY_FOLDERS_PREFIX . 'domain-mismatch',
                EASY_FOLDERS_PREFIX . 'domain-mismatch-hide',
                EASY_FOLDERS_PREFIX . 'free-to-pro-plugin-conversion-notice',
                EASY_FOLDERS_PREFIX . 'installation-steps',
                'easyfolders_updated_from_enhanced',
                'easyfolders_updated_from_wpmlf',
                'easyfolders_updated_from_wpmf',
                'easyfolders_updated_from_realmedia',
                'easyfolders_updated_from_happyfiles',
                'easyfolders_updated_from_filebird',
                'easyfolders_updated_from_wicked_folders',
                'easyfolders_updated_from_premio_folders',
                'efs-query-params',
                'easyfolders_sort_folder',
                EASY_FOLDERS_PREFIX . 'joy-ride-alert-hide',
                EASY_FOLDERS_PREFIX . 'joy-ride-tour-completed',
                EASY_FOLDERS_PREFIX . 'activating_user'
            );

            //Settings options
            $options = Easy_Folders_Helper::settingsOptions();

            foreach ($options as $key => $option) {
                array_push($wfiles_keys, EASY_FOLDERS_PREFIX .$option);
            }

            $db_keys = array();

            // Cache Keys.
            $cache_easyfolders_group = array(
                EASY_FOLDERS_PREFIX . 'settings',
            );

            if ( ! is_multisite() ) {
                // Delete Options.
                foreach ( $wfiles_keys as $key ) {
                    delete_option( $key );
                    delete_site_option( $key );
                }
            
                foreach ( $db_keys as $key ) {
                    delete_option( $key );
                    delete_site_option( $key );
                }
            
                // Delete Cache data.
                foreach ( $cache_easyfolders_group as $s_key ) {
                    wp_cache_delete( $s_key, EASY_FOLDERS_CACHE_PREFIX );
                }
            
                delete_transient( EASY_FOLDERS_PREFIX . 'conflict_check' );
            }
            
            // Delete some data incase of multisite
            if ( is_multisite() ) {
                $offset = 0;
                $limit  = 100;
                while ( $blogs = $wpdb->get_results( "SELECT blog_id FROM {$wpdb->blogs} LIMIT $offset, $limit", ARRAY_A ) ) {
                    if ( $blogs ) {
                        foreach ( $blogs as $blog ) {

                            switch_to_blog( $blog['blog_id'] );

                            foreach ( $wfiles_keys as $key ) {
                                delete_option( $key );
                                delete_site_option( $key );
                            }

                            foreach ( $db_keys as $key ) {
                                delete_option( $key );
                                delete_site_option( $key );
                            }

                            // Delete Cache data.
                            foreach ( $cache_easyfolders_group as $s_key ) {
                                wp_cache_delete( $s_key, EASY_FOLDERS_CACHE_PREFIX );
                            }

                            delete_transient( EASY_FOLDERS_PREFIX . 'conflict_check' );
                        }
                        restore_current_blog();
                    }
                    $offset += $limit;
                }
            }
		}
	}

	/**
	 * Get table
	 * @since 1.0.0
     * @return void
	 */
    private static function getTable($table)
    {
        global $wpdb;
        return $wpdb->prefix . $table;
    }
}
